@@ -21,9 +21,6 @@
  */
 
 #include <ccode/valaccodecasestatement.h>
-#include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/collection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
@@ -34,7 +31,6 @@
 
 struct _ValaCCodeCaseStatementPrivate {
 	ValaCCodeExpression* _expression;
-	GeeList* statements;
 };
 
 #define VALA_CCODE_CASE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CASE_STATEMENT, ValaCCodeCaseStatementPrivate))
@@ -49,7 +45,7 @@ static void vala_ccode_case_statement_finalize (ValaCCodeNode* obj);
 
 ValaCCodeCaseStatement* vala_ccode_case_statement_construct (GType object_type, ValaCCodeExpression* expression) {
 	ValaCCodeCaseStatement* self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (expression != NULL, NULL);
 	self = ((ValaCCodeCaseStatement*) (g_type_create_instance (object_type)));
 	vala_ccode_case_statement_set_expression (self, expression);
 	return self;
@@ -61,45 +57,20 @@ ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expr
 }
 
 
-/**
- * Append the specified statement to this switch section.
- *
- * @param stmt a statement
- */
-void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, ValaCCodeStatement* stmt) {
-	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
-	gee_collection_add (GEE_COLLECTION (self->priv->statements), stmt);
-}
-
-
 static void vala_ccode_case_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCaseStatement * self;
-	self = VALA_CCODE_CASE_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
+	self = ((ValaCCodeCaseStatement*) (base));
+	g_return_if_fail (writer != NULL);
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (((ValaCCodeNode*) (self))));
 	vala_ccode_writer_write_string (writer, "case ");
-	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_expression), writer);
+	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_expression)), writer);
 	vala_ccode_writer_write_string (writer, ":");
 	vala_ccode_writer_write_newline (writer);
-	{
-		GeeList* stmt_collection;
-		int stmt_it;
-		stmt_collection = self->priv->statements;
-		for (stmt_it = 0; stmt_it < gee_collection_get_size (GEE_COLLECTION (stmt_collection)); stmt_it = stmt_it + 1) {
-			ValaCCodeStatement* stmt;
-			stmt = ((ValaCCodeStatement*) (gee_list_get (GEE_LIST (stmt_collection), stmt_it)));
-			{
-				vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
-				(stmt == NULL ? NULL : (stmt = (vala_ccode_node_unref (stmt), NULL)));
-			}
-		}
-	}
 }
 
 
 ValaCCodeExpression* vala_ccode_case_statement_get_expression (ValaCCodeCaseStatement* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_expression;
 }
 
@@ -107,7 +78,7 @@ ValaCCodeExpression* vala_ccode_case_statement_get_expression (ValaCCodeCaseStat
 void vala_ccode_case_statement_set_expression (ValaCCodeCaseStatement* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL))), _tmp2);
@@ -124,7 +95,6 @@ static void vala_ccode_case_statement_class_init (ValaCCodeCaseStatementClass *
 
 static void vala_ccode_case_statement_instance_init (ValaCCodeCaseStatement * self) {
 	self->priv = VALA_CCODE_CASE_STATEMENT_GET_PRIVATE (self);
-	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
@@ -132,7 +102,6 @@ static void vala_ccode_case_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeCaseStatement * self;
 	self = VALA_CCODE_CASE_STATEMENT (obj);
 	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)));
-	(self->priv->statements == NULL ? NULL : (self->priv->statements = (gee_collection_object_unref (self->priv->statements), NULL)));
 	VALA_CCODE_NODE_CLASS (vala_ccode_case_statement_parent_class)->finalize (obj);
 }
 
