@@ -41,7 +41,7 @@ enum  {
 };
 static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_comma_expression_parent_class = NULL;
-static void vala_ccode_comma_expression_dispose (GObject * obj);
+static void vala_ccode_comma_expression_finalize (ValaCCodeNode* obj);
 
 
 
@@ -51,23 +51,23 @@ static void vala_ccode_comma_expression_dispose (GObject * obj);
  * @param expr a C code expression
  */
 void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* self, ValaCCodeExpression* expr) {
-	g_return_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
-	gee_collection_add (GEE_COLLECTION (self->priv->inner), expr);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (expr != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->inner)), expr);
 }
 
 
 GeeList* vala_ccode_comma_expression_get_inner (ValaCCodeCommaExpression* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->inner));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, self->priv->inner)));
 }
 
 
 static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCommaExpression * self;
 	gboolean first;
-	self = VALA_CCODE_COMMA_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = ((ValaCCodeCommaExpression*) (base));
+	g_return_if_fail (writer != NULL);
 	first = TRUE;
 	vala_ccode_writer_write_string (writer, "(");
 	{
@@ -83,8 +83,8 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 				} else {
 					first = FALSE;
 				}
-				vala_ccode_node_write (VALA_CCODE_NODE (expr), writer);
-				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
+				vala_ccode_node_write (((ValaCCodeNode*) (expr)), writer);
+				(expr == NULL ? NULL : (expr = (vala_ccode_node_unref (expr), NULL)));
 			}
 		}
 	}
@@ -95,39 +95,44 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 /**
  * Represents a comma separated expression list in the C code.
  */
-ValaCCodeCommaExpression* vala_ccode_comma_expression_new (void) {
-	ValaCCodeCommaExpression * self;
-	self = g_object_newv (VALA_TYPE_CCODE_COMMA_EXPRESSION, 0, NULL);
+ValaCCodeCommaExpression* vala_ccode_comma_expression_construct (GType object_type) {
+	ValaCCodeCommaExpression* self;
+	self = ((ValaCCodeCommaExpression*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeCommaExpression* vala_ccode_comma_expression_new (void) {
+	return vala_ccode_comma_expression_construct (VALA_TYPE_CCODE_COMMA_EXPRESSION);
+}
+
+
 static void vala_ccode_comma_expression_class_init (ValaCCodeCommaExpressionClass * klass) {
 	vala_ccode_comma_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_comma_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeCommaExpressionPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_comma_expression_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_comma_expression_real_write;
 }
 
 
 static void vala_ccode_comma_expression_instance_init (ValaCCodeCommaExpression * self) {
 	self->priv = VALA_CCODE_COMMA_EXPRESSION_GET_PRIVATE (self);
-	self->priv->inner = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->inner = ((GeeList*) (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal)));
 }
 
 
-static void vala_ccode_comma_expression_dispose (GObject * obj) {
+static void vala_ccode_comma_expression_finalize (ValaCCodeNode* obj) {
 	ValaCCodeCommaExpression * self;
 	self = VALA_CCODE_COMMA_EXPRESSION (obj);
-	(self->priv->inner == NULL ? NULL : (self->priv->inner = (g_object_unref (self->priv->inner), NULL)));
-	G_OBJECT_CLASS (vala_ccode_comma_expression_parent_class)->dispose (obj);
+	(self->priv->inner == NULL ? NULL : (self->priv->inner = (gee_collection_object_unref (self->priv->inner), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_comma_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_comma_expression_get_type (void) {
 	static GType vala_ccode_comma_expression_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_comma_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comma_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCommaExpression), 0, (GInstanceInitFunc) vala_ccode_comma_expression_instance_init };
+	if (vala_ccode_comma_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comma_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCommaExpression), 0, (GInstanceInitFunc) vala_ccode_comma_expression_instance_init, NULL };
 		vala_ccode_comma_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeCommaExpression", &g_define_type_info, 0);
 	}
 	return vala_ccode_comma_expression_type_id;
