@@ -44,7 +44,7 @@ static void vala_ccode_expression_instance_init (ValaCCodeExpression * self) {
 GType vala_ccode_expression_get_type (void) {
 	static GType vala_ccode_expression_type_id = 0;
 	if (vala_ccode_expression_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_instance_init, NULL };
 		vala_ccode_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeExpression", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_ccode_expression_type_id;
