@@ -41,36 +41,37 @@ struct _ValaCCodeForStatementPrivate {
 
 #define VALA_CCODE_FOR_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FOR_STATEMENT, ValaCCodeForStatementPrivate))
 enum  {
-	VALA_CCODE_FOR_STATEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_FOR_STATEMENT_CONDITION,
-	VALA_CCODE_FOR_STATEMENT_BODY
+	VALA_CCODE_FOR_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_for_statement_parent_class = NULL;
-static void vala_ccode_for_statement_finalize (GObject * obj);
+static void vala_ccode_for_statement_finalize (ValaCCodeNode* obj);
 
 
 
-ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body) {
-	ValaCCodeForStatement * self;
-	g_return_val_if_fail (condition == NULL || VALA_IS_CCODE_EXPRESSION (condition), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_CCODE_STATEMENT (body), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_FOR_STATEMENT, 0, NULL);
+ValaCCodeForStatement* vala_ccode_for_statement_construct (GType object_type, ValaCCodeExpression* condition, ValaCCodeStatement* body) {
+	ValaCCodeForStatement* self;
+	self = ((ValaCCodeForStatement*) (g_type_create_instance (object_type)));
 	vala_ccode_for_statement_set_condition (self, condition);
 	vala_ccode_for_statement_set_body (self, body);
 	return self;
 }
 
 
+ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body) {
+	return vala_ccode_for_statement_construct (VALA_TYPE_CCODE_FOR_STATEMENT, condition, body);
+}
+
+
 /**
  * Appends the specified expression to the list of initializers.
  *
  * @param expr an initializer expression
  */
 void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
-	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
-	gee_collection_add (GEE_COLLECTION (self->priv->initializer), expr);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (expr != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->initializer)), expr);
 }
 
 
@@ -80,19 +81,19 @@ void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, Vala
  * @param expr an iterator expression
  */
 void vala_ccode_for_statement_add_iterator (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
-	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
-	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
-	gee_collection_add (GEE_COLLECTION (self->priv->iterator), expr);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (expr != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->iterator)), expr);
 }
 
 
 static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeForStatement * self;
 	gboolean first;
-	self = VALA_CCODE_FOR_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = ((ValaCCodeForStatement*) (base));
+	g_return_if_fail (writer != NULL);
 	first = FALSE;
-	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (((ValaCCodeNode*) (self))));
 	vala_ccode_writer_write_string (writer, "for (");
 	first = TRUE;
 	{
@@ -109,15 +110,15 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 					first = FALSE;
 				}
 				if (init_expr != NULL) {
-					vala_ccode_node_write (VALA_CCODE_NODE (init_expr), writer);
+					vala_ccode_node_write (((ValaCCodeNode*) (init_expr)), writer);
 				}
-				(init_expr == NULL ? NULL : (init_expr = (g_object_unref (init_expr), NULL)));
+				(init_expr == NULL ? NULL : (init_expr = (vala_ccode_node_unref (init_expr), NULL)));
 			}
 		}
 	}
 	vala_ccode_writer_write_string (writer, "; ");
 	if (self->priv->_condition != NULL) {
-		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
+		vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_condition)), writer);
 	}
 	vala_ccode_writer_write_string (writer, "; ");
 	first = TRUE;
@@ -135,19 +136,19 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 					first = FALSE;
 				}
 				if (it_expr != NULL) {
-					vala_ccode_node_write (VALA_CCODE_NODE (it_expr), writer);
+					vala_ccode_node_write (((ValaCCodeNode*) (it_expr)), writer);
 				}
-				(it_expr == NULL ? NULL : (it_expr = (g_object_unref (it_expr), NULL)));
+				(it_expr == NULL ? NULL : (it_expr = (vala_ccode_node_unref (it_expr), NULL)));
 			}
 		}
 	}
 	vala_ccode_writer_write_string (writer, ")");
-	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
+	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_body)), writer);
 }
 
 
 ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStatement* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_condition;
 }
 
@@ -155,16 +156,15 @@ ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStateme
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "condition");
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
 ValaCCodeStatement* vala_ccode_for_statement_get_body (ValaCCodeForStatement* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_body;
 }
 
@@ -172,82 +172,43 @@ ValaCCodeStatement* vala_ccode_for_statement_get_body (ValaCCodeForStatement* se
 void vala_ccode_for_statement_set_body (ValaCCodeForStatement* self, ValaCCodeStatement* value) {
 	ValaCCodeStatement* _tmp2;
 	ValaCCodeStatement* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "body");
-}
-
-
-static void vala_ccode_for_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeForStatement * self;
-	self = VALA_CCODE_FOR_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_FOR_STATEMENT_CONDITION:
-		g_value_set_object (value, vala_ccode_for_statement_get_condition (self));
-		break;
-		case VALA_CCODE_FOR_STATEMENT_BODY:
-		g_value_set_object (value, vala_ccode_for_statement_get_body (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_for_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeForStatement * self;
-	self = VALA_CCODE_FOR_STATEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_FOR_STATEMENT_CONDITION:
-		vala_ccode_for_statement_set_condition (self, g_value_get_object (value));
-		break;
-		case VALA_CCODE_FOR_STATEMENT_BODY:
-		vala_ccode_for_statement_set_body (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_for_statement_class_init (ValaCCodeForStatementClass * klass) {
 	vala_ccode_for_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_for_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeForStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_for_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_for_statement_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_for_statement_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_for_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FOR_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FOR_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_CCODE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_for_statement_instance_init (ValaCCodeForStatement * self) {
 	self->priv = VALA_CCODE_FOR_STATEMENT_GET_PRIVATE (self);
-	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->initializer = ((GeeList*) (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal)));
+	self->priv->iterator = ((GeeList*) (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal)));
 }
 
 
-static void vala_ccode_for_statement_finalize (GObject * obj) {
+static void vala_ccode_for_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeForStatement * self;
 	self = VALA_CCODE_FOR_STATEMENT (obj);
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (g_object_unref (self->priv->initializer), NULL)));
-	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (g_object_unref (self->priv->iterator), NULL)));
-	G_OBJECT_CLASS (vala_ccode_for_statement_parent_class)->finalize (obj);
+	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)));
+	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (gee_collection_object_unref (self->priv->initializer), NULL)));
+	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (gee_collection_object_unref (self->priv->iterator), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_for_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_for_statement_get_type (void) {
 	static GType vala_ccode_for_statement_type_id = 0;
 	if (vala_ccode_for_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeForStatement), 0, (GInstanceInitFunc) vala_ccode_for_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeForStatement), 0, (GInstanceInitFunc) vala_ccode_for_statement_instance_init, NULL };
 		vala_ccode_for_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeForStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_for_statement_type_id;
