@@ -35,8 +35,8 @@ static gpointer vala_ccode_newline_parent_class = NULL;
 
 static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeNewline * self;
-	self = VALA_CCODE_NEWLINE (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = ((ValaCCodeNewline*) (base));
+	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_newline (writer);
 }
 
@@ -44,13 +44,18 @@ static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 /**
  * Represents a line break in the C code.
  */
-ValaCCodeNewline* vala_ccode_newline_new (void) {
-	ValaCCodeNewline * self;
-	self = g_object_newv (VALA_TYPE_CCODE_NEWLINE, 0, NULL);
+ValaCCodeNewline* vala_ccode_newline_construct (GType object_type) {
+	ValaCCodeNewline* self;
+	self = ((ValaCCodeNewline*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeNewline* vala_ccode_newline_new (void) {
+	return vala_ccode_newline_construct (VALA_TYPE_CCODE_NEWLINE);
+}
+
+
 static void vala_ccode_newline_class_init (ValaCCodeNewlineClass * klass) {
 	vala_ccode_newline_parent_class = g_type_class_peek_parent (klass);
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_newline_real_write;
@@ -64,7 +69,7 @@ static void vala_ccode_newline_instance_init (ValaCCodeNewline * self) {
 GType vala_ccode_newline_get_type (void) {
 	static GType vala_ccode_newline_type_id = 0;
 	if (vala_ccode_newline_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_instance_init, NULL };
 		vala_ccode_newline_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeNewline", &g_define_type_info, 0);
 	}
 	return vala_ccode_newline_type_id;
