@@ -24,13 +24,14 @@
 #include <stdio.h>
 #include <glib/gstdio.h>
 #include <ccode/valaccodelinedirective.h>
+#include <gobject/gvaluecollector.h>
 
 
 
 
 struct _ValaCCodeWriterPrivate {
-	gboolean _line_directives;
 	char* _filename;
+	gboolean _line_directives;
 	char* temp_filename;
 	gboolean file_exists;
 	FILE* stream;
@@ -40,39 +41,28 @@ struct _ValaCCodeWriterPrivate {
 
 #define VALA_CCODE_WRITER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_WRITER, ValaCCodeWriterPrivate))
 enum  {
-	VALA_CCODE_WRITER_DUMMY_PROPERTY,
-	VALA_CCODE_WRITER_FILENAME,
-	VALA_CCODE_WRITER_LINE_DIRECTIVES,
-	VALA_CCODE_WRITER_BOL
+	VALA_CCODE_WRITER_DUMMY_PROPERTY
 };
-static void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
 static gpointer vala_ccode_writer_parent_class = NULL;
-static void vala_ccode_writer_finalize (GObject * obj);
+static void vala_ccode_writer_finalize (ValaCCodeWriter* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 
-ValaCCodeWriter* vala_ccode_writer_new (const char* _filename) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeWriter * self;
-	g_return_val_if_fail (_filename != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "filename";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _filename);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_WRITER, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+ValaCCodeWriter* vala_ccode_writer_construct (GType object_type, const char* filename) {
+	ValaCCodeWriter* self;
+	g_return_val_if_fail (filename != NULL, NULL);
+	self = ((ValaCCodeWriter*) (g_type_create_instance (object_type)));
+	vala_ccode_writer_set_filename (self, filename);
 	return self;
 }
 
 
+ValaCCodeWriter* vala_ccode_writer_new (const char* filename) {
+	return vala_ccode_writer_construct (VALA_TYPE_CCODE_WRITER, filename);
+}
+
+
 /**
  * Opens the file.
  *
@@ -80,7 +70,7 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* _filename) {
  *         false otherwise
  */
 gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	self->priv->file_exists = g_file_test (self->priv->_filename, G_FILE_TEST_EXISTS);
 	if (self->priv->file_exists) {
 		char* _tmp0;
@@ -104,7 +94,7 @@ gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
 void vala_ccode_writer_close (ValaCCodeWriter* self) {
 	GError * inner_error;
 	FILE* _tmp0;
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	inner_error = NULL;
 	_tmp0 = NULL;
 	self->priv->stream = (_tmp0 = NULL, (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), _tmp0);
@@ -172,10 +162,9 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
  * Writes tabs according to the current indent level.
  */
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line) {
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
-	g_return_if_fail (line == NULL || VALA_IS_CCODE_LINE_DIRECTIVE (line));
+	g_return_if_fail (self != NULL);
 	if (self->priv->_line_directives && line != NULL) {
-		vala_ccode_node_write (VALA_CCODE_NODE (line), self);
+		vala_ccode_node_write (((ValaCCodeNode*) (line)), self);
 	}
 	if (!vala_ccode_writer_get_bol (self)) {
 		fputc ('\n', self->priv->stream);
@@ -197,7 +186,7 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
  * @param s a string
  */
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s) {
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (s != NULL);
 	fprintf (self->priv->stream, "%s", s);
 	self->priv->_bol = FALSE;
@@ -208,7 +197,7 @@ void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s) {
  * Writes a newline.
  */
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self) {
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	fputc ('\n', self->priv->stream);
 	self->priv->_bol = TRUE;
 }
@@ -218,7 +207,7 @@ void vala_ccode_writer_write_newline (ValaCCodeWriter* self) {
  * Opens a new block, increasing the indent level.
  */
 void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self) {
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	if (!vala_ccode_writer_get_bol (self)) {
 		fputc (' ', self->priv->stream);
 	} else {
@@ -234,7 +223,7 @@ void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self) {
  * Closes the current block, decreasing the indent level.
  */
 void vala_ccode_writer_write_end_block (ValaCCodeWriter* self) {
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	g_assert (self->priv->indent > 0);
 	self->priv->indent--;
 	vala_ccode_writer_write_indent (self, NULL);
@@ -252,7 +241,7 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	char** _tmp0;
 	gint lines_length1;
 	char** lines;
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (text != NULL);
 	vala_ccode_writer_write_indent (self, NULL);
 	fprintf (self->priv->stream, "/*");
@@ -289,116 +278,183 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 
 
 const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_filename;
 }
 
 
-static void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value) {
+void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "filename");
 }
 
 
 gboolean vala_ccode_writer_get_line_directives (ValaCCodeWriter* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_line_directives;
 }
 
 
 void vala_ccode_writer_set_line_directives (ValaCCodeWriter* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_line_directives = value;
-	g_object_notify (((GObject *) (self)), "line-directives");
 }
 
 
 gboolean vala_ccode_writer_get_bol (ValaCCodeWriter* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_WRITER (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_bol;
 }
 
 
-static void vala_ccode_writer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeWriter * self;
-	self = VALA_CCODE_WRITER (object);
-	switch (property_id) {
-		case VALA_CCODE_WRITER_FILENAME:
-		g_value_set_string (value, vala_ccode_writer_get_filename (self));
-		break;
-		case VALA_CCODE_WRITER_LINE_DIRECTIVES:
-		g_value_set_boolean (value, vala_ccode_writer_get_line_directives (self));
-		break;
-		case VALA_CCODE_WRITER_BOL:
-		g_value_set_boolean (value, vala_ccode_writer_get_bol (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_ccode_writer_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
+}
+
+
+static void vala_value_ccode_writer_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_ccode_writer_unref (value->data[0].v_pointer);
 	}
 }
 
 
-static void vala_ccode_writer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeWriter * self;
-	self = VALA_CCODE_WRITER (object);
-	switch (property_id) {
-		case VALA_CCODE_WRITER_FILENAME:
-		vala_ccode_writer_set_filename (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_WRITER_LINE_DIRECTIVES:
-		vala_ccode_writer_set_line_directives (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_ccode_writer_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_ccode_writer_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_value_ccode_writer_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_value_ccode_writer_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaCCodeWriter* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_value_ccode_writer_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaCCodeWriter** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_ccode_writer_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_param_spec_ccode_writer (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaParamSpecCCodeWriter* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_TYPE_CCODE_WRITER), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_value_get_ccode_writer (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CCODE_WRITER), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_value_set_ccode_writer (GValue* value, gpointer v_object) {
+	ValaCCodeWriter* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CCODE_WRITER));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_TYPE_CCODE_WRITER));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_ccode_writer_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_ccode_writer_unref (old);
 	}
 }
 
 
 static void vala_ccode_writer_class_init (ValaCCodeWriterClass * klass) {
 	vala_ccode_writer_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_WRITER_CLASS (klass)->finalize = vala_ccode_writer_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeWriterPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_writer_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_writer_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_writer_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_LINE_DIRECTIVES, g_param_spec_boolean ("line-directives", "line-directives", "line-directives", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_WRITER_BOL, g_param_spec_boolean ("bol", "bol", "bol", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
 static void vala_ccode_writer_instance_init (ValaCCodeWriter * self) {
 	self->priv = VALA_CCODE_WRITER_GET_PRIVATE (self);
 	self->priv->_bol = TRUE;
+	self->ref_count = 1;
 }
 
 
-static void vala_ccode_writer_finalize (GObject * obj) {
+static void vala_ccode_writer_finalize (ValaCCodeWriter* obj) {
 	ValaCCodeWriter * self;
 	self = VALA_CCODE_WRITER (obj);
 	self->priv->_filename = (g_free (self->priv->_filename), NULL);
 	self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL);
 	(self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)));
-	G_OBJECT_CLASS (vala_ccode_writer_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_writer_get_type (void) {
 	static GType vala_ccode_writer_type_id = 0;
 	if (vala_ccode_writer_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWriter), 0, (GInstanceInitFunc) vala_ccode_writer_instance_init };
-		vala_ccode_writer_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCCodeWriter", &g_define_type_info, 0);
+		static const GTypeValueTable g_define_type_value_table = { vala_value_ccode_writer_init, vala_value_ccode_writer_free_value, vala_value_ccode_writer_copy_value, vala_value_ccode_writer_peek_pointer, "p", vala_value_ccode_writer_collect_value, "p", vala_value_ccode_writer_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWriter), 0, (GInstanceInitFunc) vala_ccode_writer_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_ccode_writer_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaCCodeWriter", &g_define_type_info, &g_define_type_fundamental_info, 0);
 	}
 	return vala_ccode_writer_type_id;
 }
 
 
+gpointer vala_ccode_writer_ref (gpointer instance) {
+	ValaCCodeWriter* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_ccode_writer_unref (gpointer instance) {
+	ValaCCodeWriter* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_CCODE_WRITER_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
