@@ -33,14 +33,13 @@ struct _ValaAddressofExpressionPrivate {
 
 #define VALA_ADDRESSOF_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ADDRESSOF_EXPRESSION, ValaAddressofExpressionPrivate))
 enum  {
-	VALA_ADDRESSOF_EXPRESSION_DUMMY_PROPERTY,
-	VALA_ADDRESSOF_EXPRESSION_INNER
+	VALA_ADDRESSOF_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_addressof_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_addressof_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_addressof_expression_parent_class = NULL;
-static void vala_addressof_expression_dispose (GObject * obj);
+static void vala_addressof_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -50,44 +49,36 @@ static void vala_addressof_expression_dispose (GObject * obj);
  * @param inner variable whose address is to be computed
  * @return      newly created address-of expression
  */
-ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaAddressofExpression * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, inner);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_ADDRESSOF_EXPRESSION, __params_it - __params, __params);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+ValaAddressofExpression* vala_addressof_expression_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference) {
+	ValaAddressofExpression* self;
+	g_return_val_if_fail (inner != NULL, NULL);
+	self = ((ValaAddressofExpression*) (g_type_create_instance (object_type)));
+	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
+	vala_addressof_expression_set_inner (self, inner);
 	return self;
 }
 
 
+ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, ValaSourceReference* source_reference) {
+	return vala_addressof_expression_construct (VALA_TYPE_ADDRESSOF_EXPRESSION, inner, source_reference);
+}
+
+
 static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaAddressofExpression * self;
-	self = VALA_ADDRESSOF_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_addressof_expression_get_inner (self)), visitor);
+	self = ((ValaAddressofExpression*) (base));
+	g_return_if_fail (visitor != NULL);
+	vala_code_node_accept (((ValaCodeNode*) (vala_addressof_expression_get_inner (self))), visitor);
 	vala_code_visitor_visit_addressof_expression (visitor, self);
-	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
+	vala_code_visitor_visit_expression (visitor, ((ValaExpression*) (self)));
 }
 
 
 static void vala_addressof_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaAddressofExpression * self;
-	self = VALA_ADDRESSOF_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
+	self = ((ValaAddressofExpression*) (base));
+	g_return_if_fail (old_node != NULL);
+	g_return_if_fail (new_node != NULL);
 	if (vala_addressof_expression_get_inner (self) == old_node) {
 		vala_addressof_expression_set_inner (self, new_node);
 	}
@@ -96,13 +87,13 @@ static void vala_addressof_expression_real_replace_expression (ValaCodeNode* bas
 
 static gboolean vala_addressof_expression_real_is_pure (ValaExpression* base) {
 	ValaAddressofExpression * self;
-	self = VALA_ADDRESSOF_EXPRESSION (base);
+	self = ((ValaAddressofExpression*) (base));
 	return vala_expression_is_pure (vala_addressof_expression_get_inner (self));
 }
 
 
 ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* self) {
-	g_return_val_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_inner;
 }
 
@@ -110,52 +101,21 @@ ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* se
 void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value) {
 	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
-	g_return_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
-}
-
-
-static void vala_addressof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaAddressofExpression * self;
-	self = VALA_ADDRESSOF_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_ADDRESSOF_EXPRESSION_INNER:
-		g_value_set_object (value, vala_addressof_expression_get_inner (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_addressof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaAddressofExpression * self;
-	self = VALA_ADDRESSOF_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_ADDRESSOF_EXPRESSION_INNER:
-		vala_addressof_expression_set_inner (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL))), _tmp2);
+	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_inner)), ((ValaCodeNode*) (self)));
 }
 
 
 static void vala_addressof_expression_class_init (ValaAddressofExpressionClass * klass) {
 	vala_addressof_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_addressof_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaAddressofExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_addressof_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_addressof_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_addressof_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_addressof_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_addressof_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_addressof_expression_real_is_pure;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ADDRESSOF_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -164,18 +124,18 @@ static void vala_addressof_expression_instance_init (ValaAddressofExpression * s
 }
 
 
-static void vala_addressof_expression_dispose (GObject * obj) {
+static void vala_addressof_expression_finalize (ValaCodeNode* obj) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	G_OBJECT_CLASS (vala_addressof_expression_parent_class)->dispose (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)));
+	VALA_CODE_NODE_CLASS (vala_addressof_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_addressof_expression_get_type (void) {
 	static GType vala_addressof_expression_type_id = 0;
-	if (G_UNLIKELY (vala_addressof_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaAddressofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_addressof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAddressofExpression), 0, (GInstanceInitFunc) vala_addressof_expression_instance_init };
+	if (vala_addressof_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaAddressofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_addressof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAddressofExpression), 0, (GInstanceInitFunc) vala_addressof_expression_instance_init, NULL };
 		vala_addressof_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaAddressofExpression", &g_define_type_info, 0);
 	}
 	return vala_addressof_expression_type_id;
