@@ -26,14 +26,13 @@
 #include <gee/collection.h>
 #include <glib/gstdio.h>
 #include <config.h>
+#include <vala/valanamespace.h>
 #include <vala/valamethod.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefilecycle.h>
 #include <vala/valacodegenerator.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valaattribute.h>
 #include <gobject/gvaluecollector.h>
 
 
@@ -63,7 +62,6 @@ struct _ValaCodeContextPrivate {
 	ValaNamespace* _root;
 	GeeList* cycles;
 	GeeList* packages;
-	GeeList* defines;
 	ValaCodeGenerator* _codegen;
 };
 
@@ -83,7 +81,7 @@ static void vala_code_context_finalize (ValaCodeContext* obj);
  * equal to the specified version.
  */
 gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return (self->priv->_target_glib_major > major) || (self->priv->_target_glib_major == major && self->priv->_target_glib_minor >= minor);
 }
 
@@ -106,8 +104,8 @@ ValaCodeContext* vala_code_context_new (void) {
  * @return list of source files
  */
 GeeList* vala_code_context_get_source_files (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, self->priv->source_files));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, self->priv->source_files)));
 }
 
 
@@ -117,8 +115,8 @@ GeeList* vala_code_context_get_source_files (ValaCodeContext* self) {
  * @return list of C source files
  */
 GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->c_source_files));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->c_source_files)));
 }
 
 
@@ -128,9 +126,9 @@ GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self) {
  * @param file a source file
  */
 void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* file) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	g_return_if_fail (VALA_IS_SOURCE_FILE (file));
-	gee_collection_add (GEE_COLLECTION (self->priv->source_files), file);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (file != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->source_files)), file);
 }
 
 
@@ -140,9 +138,9 @@ void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* f
  * @param file a C source file
  */
 void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* file) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (file != NULL);
-	gee_collection_add (GEE_COLLECTION (self->priv->c_source_files), file);
+	gee_collection_add (((GeeCollection*) (self->priv->c_source_files)), file);
 }
 
 
@@ -152,8 +150,8 @@ void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* fil
  * @return list of used packages
  */
 GeeList* vala_code_context_get_packages (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->packages));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->packages)));
 }
 
 
@@ -164,9 +162,9 @@ GeeList* vala_code_context_get_packages (ValaCodeContext* self) {
  * @return    true if the specified package is being used
  */
 gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (pkg != NULL, FALSE);
-	return gee_collection_contains (GEE_COLLECTION (self->priv->packages), pkg);
+	return gee_collection_contains (((GeeCollection*) (self->priv->packages)), pkg);
 }
 
 
@@ -176,9 +174,9 @@ gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg)
  * @param pkg a package name
  */
 void vala_code_context_add_package (ValaCodeContext* self, const char* pkg) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (pkg != NULL);
-	gee_collection_add (GEE_COLLECTION (self->priv->packages), pkg);
+	gee_collection_add (((GeeCollection*) (self->priv->packages)), pkg);
 }
 
 
@@ -188,9 +186,9 @@ void vala_code_context_add_package (ValaCodeContext* self, const char* pkg) {
  * @param visitor the visitor to be called when traversing
  */
 void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_code_context_get_root (self)), visitor);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (visitor != NULL);
+	vala_code_node_accept (((ValaCodeNode*) (vala_code_context_get_root (self))), visitor);
 	{
 		GeeList* file_collection;
 		int file_it;
@@ -211,7 +209,7 @@ void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor)
  * Find and resolve cycles in source file dependencies.
  */
 void vala_code_context_find_header_cycles (ValaCodeContext* self) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	/* find cycles in dependencies between source files */
 	{
 		GeeList* file_collection;
@@ -229,7 +227,7 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self) {
 				if (vala_source_file_get_mark (file) == 0) {
 					GeeArrayList* _tmp0;
 					_tmp0 = NULL;
-					vala_code_context_visit (self, file, GEE_LIST ((_tmp0 = gee_array_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, g_direct_equal))));
+					vala_code_context_visit (self, file, ((GeeList*) ((_tmp0 = gee_array_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, g_direct_equal)))));
 					(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
 				}
 				(file == NULL ? NULL : (file = (vala_source_file_unref (file), NULL)));
@@ -308,8 +306,8 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self) {
 
 
 static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self, ValaSourceFile* file) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_FILE (file), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
+	g_return_val_if_fail (file != NULL, NULL);
 	{
 		GeeList* dep_collection;
 		int dep_it;
@@ -358,10 +356,10 @@ static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self,
 
 static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GeeList* chain) {
 	GeeList* l;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	g_return_if_fail (VALA_IS_SOURCE_FILE (file));
-	g_return_if_fail (GEE_IS_LIST (chain));
-	l = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, g_direct_equal));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (file != NULL);
+	g_return_if_fail (chain != NULL);
+	l = ((GeeList*) (gee_array_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, g_direct_equal)));
 	{
 		GeeList* chain_file_collection;
 		int chain_file_it;
@@ -370,12 +368,12 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 			ValaSourceFile* chain_file;
 			chain_file = ((ValaSourceFile*) (gee_list_get (GEE_LIST (chain_file_collection), chain_file_it)));
 			{
-				gee_collection_add (GEE_COLLECTION (l), chain_file);
+				gee_collection_add (((GeeCollection*) (l)), chain_file);
 				(chain_file == NULL ? NULL : (chain_file = (vala_source_file_unref (chain_file), NULL)));
 			}
 		}
 	}
-	gee_collection_add (GEE_COLLECTION (l), file);
+	gee_collection_add (((GeeCollection*) (l)), file);
 	/* mark file as currently being visited */
 	vala_source_file_set_mark (file, 1);
 	{
@@ -397,7 +395,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 					gboolean cycle_start_found;
 					/* found cycle */
 					cycle = vala_source_file_cycle_new ();
-					gee_collection_add (GEE_COLLECTION (self->priv->cycles), cycle);
+					gee_collection_add (((GeeCollection*) (self->priv->cycles)), cycle);
 					cycle_start_found = FALSE;
 					{
 						GeeList* cycle_file_collection;
@@ -430,7 +428,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 										continue;
 									}
 									/* file is in an other cycle, merge the two cycles */
-									gee_collection_remove (GEE_COLLECTION (self->priv->cycles), vala_source_file_get_cycle (cycle_file));
+									gee_collection_remove (((GeeCollection*) (self->priv->cycles)), vala_source_file_get_cycle (cycle_file));
 									{
 										GeeList* inner_cycle_file_collection;
 										int inner_cycle_file_it;
@@ -443,7 +441,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 											{
 												if (vala_source_file_get_cycle (inner_cycle_file) != cycle) {
 													/* file in inner cycle not yet added to outer cycle */
-													gee_collection_add (GEE_COLLECTION (cycle->files), inner_cycle_file);
+													gee_collection_add (((GeeCollection*) (cycle->files)), inner_cycle_file);
 													vala_source_file_set_cycle (inner_cycle_file, cycle);
 												}
 												(inner_cycle_file == NULL ? NULL : (inner_cycle_file = (vala_source_file_unref (inner_cycle_file), NULL)));
@@ -451,7 +449,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 										}
 									}
 								} else {
-									gee_collection_add (GEE_COLLECTION (cycle->files), cycle_file);
+									gee_collection_add (((GeeCollection*) (cycle->files)), cycle_file);
 									vala_source_file_set_cycle (cycle_file, cycle);
 								}
 								(cycle_file == NULL ? NULL : (cycle_file = (vala_source_file_unref (cycle_file), NULL)));
@@ -477,43 +475,12 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 }
 
 
-void vala_code_context_add_define (ValaCodeContext* self, const char* define) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	g_return_if_fail (define != NULL);
-	gee_collection_add (GEE_COLLECTION (self->priv->defines), define);
-}
-
-
-gboolean vala_code_context_ignore_node (ValaCodeContext* self, ValaCodeNode* node) {
-	ValaAttribute* attr;
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
-	g_return_val_if_fail (VALA_IS_CODE_NODE (node), FALSE);
-	attr = vala_code_node_get_attribute (node, "Conditional");
-	if (attr == NULL) {
-		gboolean _tmp0;
-		return (_tmp0 = FALSE, (attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL))), _tmp0);
-	} else {
-		char* condition;
-		condition = vala_attribute_get_string (attr, "condition");
-		if (condition == NULL) {
-			gboolean _tmp1;
-			return (_tmp1 = FALSE, (condition = (g_free (condition), NULL)), (attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL))), _tmp1);
-		} else {
-			gboolean _tmp2;
-			return (_tmp2 = !gee_collection_contains (GEE_COLLECTION (self->priv->defines), condition), (condition = (g_free (condition), NULL)), (attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL))), _tmp2);
-		}
-		condition = (g_free (condition), NULL);
-	}
-	(attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL)));
-}
-
-
 char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg, int vapi_directories_length1, char** vapi_directories) {
 	char* basename;
 	char* filename;
 	char* _tmp3;
 	char* _tmp8;
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (pkg != NULL, NULL);
 	basename = g_strdup_printf ("%s.vapi", pkg);
 	filename = NULL;
@@ -580,7 +547,7 @@ char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg
 
 
 const char* vala_code_context_get_library (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_library;
 }
 
@@ -588,7 +555,7 @@ const char* vala_code_context_get_library (ValaCodeContext* self) {
 void vala_code_context_set_library (ValaCodeContext* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_library = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_library = (g_free (self->priv->_library), NULL)), _tmp2);
@@ -596,91 +563,91 @@ void vala_code_context_set_library (ValaCodeContext* self, const char* value) {
 
 
 gboolean vala_code_context_get_memory_management (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_memory_management;
 }
 
 
 void vala_code_context_set_memory_management (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_memory_management = value;
 }
 
 
 gboolean vala_code_context_get_assert (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_assert;
 }
 
 
 void vala_code_context_set_assert (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_assert = value;
 }
 
 
 gboolean vala_code_context_get_checking (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_checking;
 }
 
 
 void vala_code_context_set_checking (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_checking = value;
 }
 
 
 gboolean vala_code_context_get_non_null (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_non_null;
 }
 
 
 void vala_code_context_set_non_null (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_non_null = value;
 }
 
 
 gboolean vala_code_context_get_non_null_experimental (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_non_null_experimental;
 }
 
 
 void vala_code_context_set_non_null_experimental (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_non_null_experimental = value;
 }
 
 
 gboolean vala_code_context_get_ccode_only (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_ccode_only;
 }
 
 
 void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_ccode_only = value;
 }
 
 
 gboolean vala_code_context_get_compile_only (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_compile_only;
 }
 
 
 void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_compile_only = value;
 }
 
 
 const char* vala_code_context_get_output (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_output;
 }
 
@@ -688,7 +655,7 @@ const char* vala_code_context_get_output (ValaCodeContext* self) {
 void vala_code_context_set_output (ValaCodeContext* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_output = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_output = (g_free (self->priv->_output), NULL)), _tmp2);
@@ -696,7 +663,7 @@ void vala_code_context_set_output (ValaCodeContext* self, const char* value) {
 
 
 const char* vala_code_context_get_basedir (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_basedir;
 }
 
@@ -704,7 +671,7 @@ const char* vala_code_context_get_basedir (ValaCodeContext* self) {
 void vala_code_context_set_basedir (ValaCodeContext* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_basedir = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_basedir = (g_free (self->priv->_basedir), NULL)), _tmp2);
@@ -712,7 +679,7 @@ void vala_code_context_set_basedir (ValaCodeContext* self, const char* value) {
 
 
 const char* vala_code_context_get_directory (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_directory;
 }
 
@@ -720,7 +687,7 @@ const char* vala_code_context_get_directory (ValaCodeContext* self) {
 void vala_code_context_set_directory (ValaCodeContext* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_directory = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_directory = (g_free (self->priv->_directory), NULL)), _tmp2);
@@ -728,43 +695,43 @@ void vala_code_context_set_directory (ValaCodeContext* self, const char* value)
 
 
 gboolean vala_code_context_get_debug (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_debug;
 }
 
 
 void vala_code_context_set_debug (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_debug = value;
 }
 
 
 gint vala_code_context_get_optlevel (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	return self->priv->_optlevel;
 }
 
 
 void vala_code_context_set_optlevel (ValaCodeContext* self, gint value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_optlevel = value;
 }
 
 
 gboolean vala_code_context_get_thread (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_thread;
 }
 
 
 void vala_code_context_set_thread (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_thread = value;
 }
 
 
 ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_module_init_method;
 }
 
@@ -772,7 +739,7 @@ ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self) {
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value) {
 	ValaMethod* _tmp2;
 	ValaMethod* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_module_init_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_module_init_method == NULL ? NULL : (self->priv->_module_init_method = (vala_code_node_unref (self->priv->_module_init_method), NULL))), _tmp2);
@@ -780,61 +747,61 @@ void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod
 
 
 gboolean vala_code_context_get_save_temps (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_save_temps;
 }
 
 
 void vala_code_context_set_save_temps (ValaCodeContext* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_save_temps = value;
 }
 
 
 gint vala_code_context_get_target_glib_major (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	return self->priv->_target_glib_major;
 }
 
 
 void vala_code_context_set_target_glib_major (ValaCodeContext* self, gint value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_target_glib_major = value;
 }
 
 
 gint vala_code_context_get_target_glib_minor (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	return self->priv->_target_glib_minor;
 }
 
 
 void vala_code_context_set_target_glib_minor (ValaCodeContext* self, gint value) {
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_target_glib_minor = value;
 }
 
 
 gboolean vala_code_context_get_save_csources (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_save_temps;
 }
 
 
 gboolean vala_code_context_get_save_cheaders (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return vala_code_context_get_save_csources (self) || NULL != self->priv->_library;
 }
 
 
 ValaNamespace* vala_code_context_get_root (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_root;
 }
 
 
 ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self) {
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_codegen;
 }
 
@@ -842,7 +809,7 @@ ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self) {
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value) {
 	ValaCodeGenerator* _tmp2;
 	ValaCodeGenerator* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_codegen = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_visitor_ref (_tmp1))), (self->priv->_codegen == NULL ? NULL : (self->priv->_codegen = (vala_code_visitor_unref (self->priv->_codegen), NULL))), _tmp2);
@@ -949,12 +916,11 @@ static void vala_code_context_class_init (ValaCodeContextClass * klass) {
 
 static void vala_code_context_instance_init (ValaCodeContext * self) {
 	self->priv = VALA_CODE_CONTEXT_GET_PRIVATE (self);
-	self->priv->source_files = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, g_direct_equal));
-	self->priv->c_source_files = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
+	self->priv->source_files = ((GeeList*) (gee_array_list_new (VALA_TYPE_SOURCE_FILE, ((GBoxedCopyFunc) (vala_source_file_ref)), vala_source_file_unref, g_direct_equal)));
+	self->priv->c_source_files = ((GeeList*) (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)));
 	self->priv->_root = vala_namespace_new (NULL, NULL);
-	self->priv->cycles = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE_CYCLE, ((GBoxedCopyFunc) (vala_source_file_cycle_ref)), vala_source_file_cycle_unref, g_direct_equal));
-	self->priv->packages = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal));
-	self->priv->defines = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal));
+	self->priv->cycles = ((GeeList*) (gee_array_list_new (VALA_TYPE_SOURCE_FILE_CYCLE, ((GBoxedCopyFunc) (vala_source_file_cycle_ref)), vala_source_file_cycle_unref, g_direct_equal)));
+	self->priv->packages = ((GeeList*) (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal)));
 	self->priv->_codegen = vala_code_generator_new ();
 	self->ref_count = 1;
 }
@@ -973,7 +939,6 @@ static void vala_code_context_finalize (ValaCodeContext* obj) {
 	(self->priv->_root == NULL ? NULL : (self->priv->_root = (vala_code_node_unref (self->priv->_root), NULL)));
 	(self->priv->cycles == NULL ? NULL : (self->priv->cycles = (gee_collection_object_unref (self->priv->cycles), NULL)));
 	(self->priv->packages == NULL ? NULL : (self->priv->packages = (gee_collection_object_unref (self->priv->packages), NULL)));
-	(self->priv->defines == NULL ? NULL : (self->priv->defines = (gee_collection_object_unref (self->priv->defines), NULL)));
 	(self->priv->_codegen == NULL ? NULL : (self->priv->_codegen = (vala_code_visitor_unref (self->priv->_codegen), NULL)));
 }
 
