@@ -21,16 +21,16 @@
  */
 
 #include <vala/valacodenode.h>
+#include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <gee/arraylist.h>
-#include <gee/collection.h>
 #include <ccode/valaccodelinedirective.h>
 #include <vala/valasourcereference.h>
-#include <vala/valadatatype.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valadatatype.h>
+#include <vala/valasemanticanalyzer.h>
 #include <vala/valaexpression.h>
 #include <vala/valaattribute.h>
-#include <vala/valacodegenerator.h>
 #include <vala/valasourcefile.h>
 #include <gobject/gvaluecollector.h>
 
@@ -40,9 +40,9 @@
 struct _ValaCodeNodePrivate {
 	ValaCodeNode* _parent_node;
 	ValaSourceReference* _source_reference;
+	gboolean _checked;
 	gboolean _error;
 	GeeList* _error_types;
-	ValaCodeBinding* code_binding;
 	ValaCCodeNode* _ccodenode;
 };
 
@@ -54,10 +54,10 @@ static void _g_list_free_vala_code_node_unref (GList* self);
 static GeeList* vala_code_node__empty_type_list;
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
+static gboolean vala_code_node_real_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
-static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
 static gpointer vala_code_node_parent_class = NULL;
 static void vala_code_node_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -75,7 +75,7 @@ static void _g_list_free_vala_code_node_unref (GList* self) {
  */
 GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
 	GeeList* _tmp4;
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_error_types != NULL) {
 		GeeList* _tmp0;
 		_tmp0 = NULL;
@@ -86,7 +86,7 @@ GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
 		GeeArrayList* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		vala_code_node__empty_type_list = (_tmp3 = GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, GEE_LIST ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal))))), (vala_code_node__empty_type_list == NULL ? NULL : (vala_code_node__empty_type_list = (gee_collection_object_unref (vala_code_node__empty_type_list), NULL))), _tmp3);
+		vala_code_node__empty_type_list = (_tmp3 = ((GeeList*) (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, ((GeeList*) ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal))))))), (vala_code_node__empty_type_list == NULL ? NULL : (vala_code_node__empty_type_list = (gee_collection_object_unref (vala_code_node__empty_type_list), NULL))), _tmp3);
 		(_tmp2 == NULL ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)));
 	}
 	_tmp4 = NULL;
@@ -99,15 +99,15 @@ GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
  * or a child node 
  */
 void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_DATA_TYPE (error_type));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (error_type != NULL);
 	if (self->priv->_error_types == NULL) {
 		GeeList* _tmp0;
 		_tmp0 = NULL;
-		self->priv->_error_types = (_tmp0 = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)), (self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL))), _tmp0);
+		self->priv->_error_types = (_tmp0 = ((GeeList*) (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal))), (self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL))), _tmp0);
 	}
-	gee_collection_add (GEE_COLLECTION (self->priv->_error_types), error_type);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (error_type), self);
+	gee_collection_add (((GeeCollection*) (self->priv->_error_types)), error_type);
+	vala_code_node_set_parent_node (((ValaCodeNode*) (error_type)), self);
 }
 
 
@@ -116,8 +116,8 @@ void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type
  * or a child node 
  */
 void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (GEE_IS_LIST (error_types));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (error_types != NULL);
 	{
 		GeeList* error_type_collection;
 		int error_type_it;
@@ -140,8 +140,8 @@ void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types) {
  * @param visitor the visitor to be called while traversing
  */
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (visitor != NULL);
 }
 
 
@@ -156,8 +156,8 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
  * @param visitor the visitor to be called while traversing
  */
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (visitor != NULL);
 }
 
 
@@ -166,10 +166,22 @@ void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visito
 }
 
 
+static gboolean vala_code_node_real_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer) {
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	return FALSE;
+}
+
+
+gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer) {
+	return VALA_CODE_NODE_GET_CLASS (self)->check (self, analyzer);
+}
+
+
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (old_type != NULL);
+	g_return_if_fail (new_type != NULL);
 }
 
 
@@ -179,9 +191,9 @@ void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, Va
 
 
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (old_node != NULL);
+	g_return_if_fail (new_node != NULL);
 }
 
 
@@ -197,7 +209,7 @@ void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_
  * @return     attribute
  */
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	/* FIXME: use hash table*/
 	{
@@ -230,7 +242,7 @@ static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 	GString* str;
 	const char* _tmp1;
 	char* _tmp2;
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("");
 	g_string_append (str, "/* ");
 	if (self->priv->_source_reference != NULL) {
@@ -250,54 +262,20 @@ char* vala_code_node_to_string (ValaCodeNode* self) {
 }
 
 
-/**
- * Returns the binding to the generated code.
- *
- * @return code binding
- */
-ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
-	ValaCodeBinding* _tmp1;
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
-	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
-	if (self->priv->code_binding == NULL) {
-		ValaCodeBinding* _tmp0;
-		_tmp0 = NULL;
-		self->priv->code_binding = (_tmp0 = vala_code_node_create_code_binding (self, codegen), (self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (vala_code_binding_unref (self->priv->code_binding), NULL))), _tmp0);
-	}
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->code_binding, (_tmp1 == NULL ? NULL : vala_code_binding_ref (_tmp1)));
-}
-
-
-/**
- * Creates the binding to the generated code.
- */
-static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
-	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
-	return NULL;
-}
-
-
-ValaCodeBinding* vala_code_node_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
-	return VALA_CODE_NODE_GET_CLASS (self)->create_code_binding (self, codegen);
-}
-
-
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_parent_node;
 }
 
 
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_parent_node = value;
 }
 
 
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_source_reference;
 }
 
@@ -305,7 +283,7 @@ ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self) {
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value) {
 	ValaSourceReference* _tmp2;
 	ValaSourceReference* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_reference_ref (_tmp1))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL))), _tmp2);
@@ -313,7 +291,7 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 
 
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_ccodenode;
 }
 
@@ -321,7 +299,7 @@ ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self) {
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 	ValaCCodeNode* _tmp4;
 	ValaCCodeNode* _tmp3;
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (self != NULL);
 	if (value != NULL && self->priv->_source_reference != NULL) {
 		ValaCCodeLineDirective* _tmp2;
 		char* _tmp1;
@@ -337,21 +315,33 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 }
 
 
+gboolean vala_code_node_get_checked (ValaCodeNode* self) {
+	g_return_val_if_fail (self != NULL, FALSE);
+	return self->priv->_checked;
+}
+
+
+void vala_code_node_set_checked (ValaCodeNode* self, gboolean value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_checked = value;
+}
+
+
 gboolean vala_code_node_get_error (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_error;
 }
 
 
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_error = value;
 }
 
 
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
-	return self->priv->_error_types != NULL && gee_collection_get_size (GEE_COLLECTION (self->priv->_error_types)) > 0;
+	g_return_val_if_fail (self != NULL, FALSE);
+	return self->priv->_error_types != NULL && gee_collection_get_size (((GeeCollection*) (self->priv->_error_types))) > 0;
 }
 
 
@@ -452,10 +442,10 @@ static void vala_code_node_class_init (ValaCodeNodeClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaCodeNodePrivate));
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_code_node_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_code_node_real_accept_children;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_code_node_real_check;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_code_node_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_code_node_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_code_node_real_to_string;
-	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_code_node_real_create_code_binding;
 }
 
 
@@ -471,7 +461,6 @@ static void vala_code_node_finalize (ValaCodeNode* obj) {
 	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)));
 	(self->attributes == NULL ? NULL : (self->attributes = (_g_list_free_vala_code_node_unref (self->attributes), NULL)));
 	(self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL)));
-	(self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (vala_code_binding_unref (self->priv->code_binding), NULL)));
 	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL)));
 }
 
