@@ -42,19 +42,24 @@ static ValaStatementIface* vala_continue_statement_vala_statement_parent_iface =
  * @param source reference to source code
  * @return       newly created continue statement
  */
-ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source) {
-	ValaContinueStatement * self;
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, 0, NULL);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+ValaContinueStatement* vala_continue_statement_construct (GType object_type, ValaSourceReference* source) {
+	ValaContinueStatement* self;
+	g_return_val_if_fail (source != NULL, NULL);
+	self = ((ValaContinueStatement*) (g_type_create_instance (object_type)));
+	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source);
 	return self;
 }
 
 
+ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source) {
+	return vala_continue_statement_construct (VALA_TYPE_CONTINUE_STATEMENT, source);
+}
+
+
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaContinueStatement * self;
-	self = VALA_CONTINUE_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaContinueStatement*) (base));
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_continue_statement (visitor, self);
 }
 
@@ -77,7 +82,7 @@ static void vala_continue_statement_instance_init (ValaContinueStatement * self)
 GType vala_continue_statement_get_type (void) {
 	static GType vala_continue_statement_type_id = 0;
 	if (vala_continue_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_continue_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_continue_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaContinueStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_continue_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
