@@ -26,6 +26,7 @@
 #include <gee/readonlylist.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valadatatype.h>
@@ -34,7 +35,6 @@
 #include <vala/valascope.h>
 #include <vala/valamethod.h>
 #include <vala/valamember.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 #include <vala/valareferencetype.h>
 
@@ -55,13 +55,7 @@ struct _ValaDelegatePrivate {
 
 #define VALA_DELEGATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DELEGATE, ValaDelegatePrivate))
 enum  {
-	VALA_DELEGATE_DUMMY_PROPERTY,
-	VALA_DELEGATE_RETURN_TYPE,
-	VALA_DELEGATE_HAS_TARGET,
-	VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION,
-	VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION,
-	VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION,
-	VALA_DELEGATE_NO_ARRAY_LENGTH
+	VALA_DELEGATE_DUMMY_PROPERTY
 };
 static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -75,9 +69,8 @@ static char* vala_delegate_real_get_set_value_function (ValaTypeSymbol* base);
 static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static char* vala_delegate_get_return_type_string (ValaDelegate* self);
 static char* vala_delegate_get_parameters_string (ValaDelegate* self);
-static GObject * vala_delegate_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_delegate_parent_class = NULL;
-static void vala_delegate_finalize (GObject * obj);
+static void vala_delegate_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -91,29 +84,36 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source      reference to source code
  * @return            newly created delegate
  */
-ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
-	ValaDelegate * self;
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_DELEGATE, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
+ValaDelegate* vala_delegate_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+	ValaDelegate* self;
+	g_return_val_if_fail (return_type != NULL, NULL);
+	self = ((ValaDelegate*) (g_type_create_instance (object_type)));
+	self = ((ValaDelegate*) (vala_typesymbol_construct (object_type, name, source_reference)));
 	vala_delegate_set_return_type (self, return_type);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	/* error is -1 (right of user_data)*/
+	vala_delegate_set_cinstance_parameter_position (self, ((double) (-2)));
+	vala_delegate_set_carray_length_parameter_position (self, ((double) (-3)));
+	vala_delegate_set_cdelegate_target_parameter_position (self, ((double) (-3)));
 	return self;
 }
 
 
+ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+	return vala_delegate_construct (VALA_TYPE_DELEGATE, name, return_type, source_reference);
+}
+
+
 /**
  * Appends the specified parameter to the list of type parameters.
  *
  * @param p a type parameter
  */
 void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
-	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
-	p->type = VALA_TYPESYMBOL (self);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (p != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->type_parameters)), p);
+	p->type = ((ValaTypeSymbol*) (self));
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) (self))), vala_symbol_get_name (((ValaSymbol*) (p))), ((ValaSymbol*) (p)));
 }
 
 
@@ -123,17 +123,17 @@ void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p)
  * @param param a formal parameter
  */
 void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (param != NULL);
 	if (vala_delegate_get_no_array_length (self)) {
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
 	/* default C parameter position*/
-	vala_formal_parameter_set_cparameter_position (param, ((double) (gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1)));
+	vala_formal_parameter_set_cparameter_position (param, ((double) (gee_collection_get_size (((GeeCollection*) (self->priv->parameters))) + 1)));
 	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
-	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
+	gee_collection_add (((GeeCollection*) (self->priv->parameters)), param);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) (self))), vala_symbol_get_name (((ValaSymbol*) (param))), ((ValaSymbol*) (param)));
 }
 
 
@@ -143,8 +143,8 @@ void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param
  * @return parameter list
  */
 GeeList* vala_delegate_get_parameters (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->parameters));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->parameters)));
 }
 
 
@@ -160,14 +160,14 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 	GeeIterator* method_params_it;
 	gboolean first;
 	gboolean _tmp3;
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
-	g_return_val_if_fail (VALA_IS_METHOD (m), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (m != NULL, FALSE);
 	/* method is allowed to ensure stricter return type (stronger postcondition)*/
 	if (!vala_data_type_stricter (vala_method_get_return_type (m), vala_delegate_get_return_type (self))) {
 		return FALSE;
 	}
 	method_params = vala_method_get_parameters (m);
-	method_params_it = gee_iterable_iterator (GEE_ITERABLE (method_params));
+	method_params_it = gee_iterable_iterator (((GeeIterable*) (method_params)));
 	first = TRUE;
 	{
 		GeeList* param_collection;
@@ -184,46 +184,46 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 				 */
 				if (first && vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE && !self->priv->_has_target) {
 					first = FALSE;
-					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+					(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 					continue;
 				}
 				/* method is allowed to accept less arguments */
 				if (!gee_iterator_next (method_params_it)) {
-					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+					(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 					break;
 				}
 				/* method is allowed to accept arguments of looser types (weaker precondition)*/
 				method_param = ((ValaFormalParameter*) (gee_iterator_get (method_params_it)));
 				if (!vala_data_type_stricter (vala_formal_parameter_get_parameter_type (param), vala_formal_parameter_get_parameter_type (method_param))) {
 					gboolean _tmp1;
-					return (_tmp1 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp1);
+					return (_tmp1 = FALSE, (param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (vala_code_node_unref (method_param), NULL))), (method_params == NULL ? NULL : (method_params = (gee_collection_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (gee_collection_object_unref (method_params_it), NULL))), _tmp1);
 				}
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
-				(method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
+				(method_param == NULL ? NULL : (method_param = (vala_code_node_unref (method_param), NULL)));
 			}
 		}
 	}
 	/* method may not expect more arguments */
 	if (gee_iterator_next (method_params_it)) {
 		gboolean _tmp2;
-		return (_tmp2 = FALSE, (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp2);
+		return (_tmp2 = FALSE, (method_params == NULL ? NULL : (method_params = (gee_collection_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (gee_collection_object_unref (method_params_it), NULL))), _tmp2);
 	}
-	return (_tmp3 = TRUE, (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp3);
+	return (_tmp3 = TRUE, (method_params == NULL ? NULL : (method_params = (gee_collection_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (gee_collection_object_unref (method_params_it), NULL))), _tmp3);
 }
 
 
 static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaDelegate*) (base));
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_delegate (visitor, self);
 }
 
 
 static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaDelegate*) (base));
+	g_return_if_fail (visitor != NULL);
 	{
 		GeeList* p_collection;
 		int p_it;
@@ -232,12 +232,12 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 			ValaTypeParameter* p;
 			p = ((ValaTypeParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
 			{
-				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
-				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
+				vala_code_node_accept (((ValaCodeNode*) (p)), visitor);
+				(p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL)));
 			}
 		}
 	}
-	vala_code_node_accept (VALA_CODE_NODE (vala_delegate_get_return_type (self)), visitor);
+	vala_code_node_accept (((ValaCodeNode*) (vala_delegate_get_return_type (self))), visitor);
 	{
 		GeeList* param_collection;
 		int param_it;
@@ -246,8 +246,8 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 			ValaFormalParameter* param;
 			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
-				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				vala_code_node_accept (((ValaCodeNode*) (param)), visitor);
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 			}
 		}
 	}
@@ -257,13 +257,13 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 static char* vala_delegate_real_get_cname (ValaTypeSymbol* base, gboolean const_type) {
 	ValaDelegate * self;
 	const char* _tmp2;
-	self = VALA_DELEGATE (base);
+	self = ((ValaDelegate*) (base));
 	if (self->priv->cname == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) (self))))), vala_symbol_get_name (((ValaSymbol*) (self)))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
@@ -279,7 +279,7 @@ static char* vala_delegate_real_get_cname (ValaTypeSymbol* base, gboolean const_
 void vala_delegate_set_cname (ValaDelegate* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
@@ -288,8 +288,8 @@ void vala_delegate_set_cname (ValaDelegate* self, const char* cname) {
 
 
 static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttribute* a) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -320,7 +320,7 @@ static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttri
 				_tmp1 = NULL;
 				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 				{
-					vala_typesymbol_add_cheader_filename (VALA_TYPESYMBOL (self), filename);
+					vala_typesymbol_add_cheader_filename (((ValaTypeSymbol*) (self)), filename);
 					filename = (g_free (filename), NULL);
 				}
 			}
@@ -335,16 +335,16 @@ static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttri
  * Process all associated attributes.
  */
 void vala_delegate_process_attributes (ValaDelegate* self) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = VALA_CODE_NODE (self)->attributes;
+		a_collection = ((ValaCodeNode*) (self))->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_delegate_process_ccode_attribute (self, a);
@@ -353,7 +353,7 @@ void vala_delegate_process_attributes (ValaDelegate* self) {
 						vala_delegate_set_no_array_length (self, TRUE);
 					}
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -362,44 +362,44 @@ void vala_delegate_process_attributes (ValaDelegate* self) {
 
 static gboolean vala_delegate_real_is_reference_type (ValaTypeSymbol* base) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
+	self = ((ValaDelegate*) (base));
 	return FALSE;
 }
 
 
 static char* vala_delegate_real_get_type_id (ValaTypeSymbol* base) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
+	self = ((ValaDelegate*) (base));
 	return g_strdup ("G_TYPE_POINTER");
 }
 
 
 static char* vala_delegate_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
+	self = ((ValaDelegate*) (base));
 	return g_strdup ("POINTER");
 }
 
 
 static char* vala_delegate_real_get_get_value_function (ValaTypeSymbol* base) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
+	self = ((ValaDelegate*) (base));
 	return g_strdup ("g_value_get_pointer");
 }
 
 
 static char* vala_delegate_real_get_set_value_function (ValaTypeSymbol* base) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
+	self = ((ValaDelegate*) (base));
 	return g_strdup ("g_value_set_pointer");
 }
 
 
 static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaDelegate * self;
-	self = VALA_DELEGATE (base);
-	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	self = ((ValaDelegate*) (base));
+	g_return_if_fail (old_type != NULL);
+	g_return_if_fail (new_type != NULL);
 	if (vala_delegate_get_return_type (self) == old_type) {
 		vala_delegate_set_return_type (self, new_type);
 	}
@@ -410,7 +410,7 @@ char* vala_delegate_get_prototype_string (ValaDelegate* self, const char* name)
 	char* _tmp1;
 	char* _tmp0;
 	char* _tmp2;
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
@@ -423,7 +423,7 @@ static char* vala_delegate_get_return_type_string (ValaDelegate* self) {
 	char* str;
 	char* _tmp2;
 	char* _tmp1;
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	str = g_strdup ("");
 	if (!vala_data_type_get_value_owned (vala_delegate_get_return_type (self)) && VALA_IS_REFERENCE_TYPE (vala_delegate_get_return_type (self))) {
 		char* _tmp0;
@@ -432,7 +432,7 @@ static char* vala_delegate_get_return_type_string (ValaDelegate* self) {
 	}
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	str = (_tmp2 = g_strconcat (str, (_tmp1 = (vala_code_node_to_string (VALA_CODE_NODE (vala_delegate_get_return_type (self))))), NULL), (str = (g_free (str), NULL)), _tmp2);
+	str = (_tmp2 = g_strconcat (str, (_tmp1 = (vala_code_node_to_string (((ValaCodeNode*) (vala_delegate_get_return_type (self)))))), NULL), (str = (g_free (str), NULL)), _tmp2);
 	_tmp1 = (g_free (_tmp1), NULL);
 	return str;
 }
@@ -442,7 +442,7 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 	char* str;
 	gint i;
 	char* _tmp7;
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	str = g_strdup ("(");
 	i = 1;
 	{
@@ -480,7 +480,7 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 				}
 				_tmp5 = NULL;
 				_tmp4 = NULL;
-				str = (_tmp5 = g_strconcat (str, (_tmp4 = (vala_code_node_to_string (VALA_CODE_NODE (vala_formal_parameter_get_parameter_type (param))))), NULL), (str = (g_free (str), NULL)), _tmp5);
+				str = (_tmp5 = g_strconcat (str, (_tmp4 = (vala_code_node_to_string (((ValaCodeNode*) (vala_formal_parameter_get_parameter_type (param)))))), NULL), (str = (g_free (str), NULL)), _tmp5);
 				_tmp4 = (g_free (_tmp4), NULL);
 				if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_IN && vala_data_type_get_value_owned (vala_formal_parameter_get_parameter_type (param))) {
 					char* _tmp6;
@@ -488,7 +488,7 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 					str = (_tmp6 = g_strconcat (str, ("#"), NULL), (str = (g_free (str), NULL)), _tmp6);
 				}
 				i++;
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 			}
 		}
 	}
@@ -499,7 +499,7 @@ static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
 
 
 ValaDataType* vala_delegate_get_return_type (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_return_type;
 }
 
@@ -507,75 +507,70 @@ ValaDataType* vala_delegate_get_return_type (ValaDelegate* self) {
 void vala_delegate_set_return_type (ValaDelegate* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "return-type");
+	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_return_type)), ((ValaCodeNode*) (self)));
 }
 
 
 gboolean vala_delegate_get_has_target (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_has_target;
 }
 
 
 void vala_delegate_set_has_target (ValaDelegate* self, gboolean value) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_has_target = value;
-	g_object_notify (((GObject *) (self)), "has-target");
 }
 
 
 double vala_delegate_get_cinstance_parameter_position (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), 0.0);
+	g_return_val_if_fail (self != NULL, 0.0);
 	return self->priv->_cinstance_parameter_position;
 }
 
 
 void vala_delegate_set_cinstance_parameter_position (ValaDelegate* self, double value) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_cinstance_parameter_position = value;
-	g_object_notify (((GObject *) (self)), "cinstance-parameter-position");
 }
 
 
 double vala_delegate_get_carray_length_parameter_position (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), 0.0);
+	g_return_val_if_fail (self != NULL, 0.0);
 	return self->priv->_carray_length_parameter_position;
 }
 
 
 void vala_delegate_set_carray_length_parameter_position (ValaDelegate* self, double value) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_carray_length_parameter_position = value;
-	g_object_notify (((GObject *) (self)), "carray-length-parameter-position");
 }
 
 
 double vala_delegate_get_cdelegate_target_parameter_position (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), 0.0);
+	g_return_val_if_fail (self != NULL, 0.0);
 	return self->priv->_cdelegate_target_parameter_position;
 }
 
 
 void vala_delegate_set_cdelegate_target_parameter_position (ValaDelegate* self, double value) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_cdelegate_target_parameter_position = value;
-	g_object_notify (((GObject *) (self)), "cdelegate-target-parameter-position");
 }
 
 
 gboolean vala_delegate_get_no_array_length (ValaDelegate* self) {
-	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_no_array_length;
 }
 
 
 void vala_delegate_set_no_array_length (ValaDelegate* self, gboolean value) {
-	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_no_array_length = value;
 	{
 		GeeList* param_collection;
@@ -586,97 +581,17 @@ void vala_delegate_set_no_array_length (ValaDelegate* self, gboolean value) {
 			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_formal_parameter_set_no_array_length (param, value);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 			}
 		}
 	}
-	g_object_notify (((GObject *) (self)), "no-array-length");
-}
-
-
-static GObject * vala_delegate_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	ValaDelegateClass * klass;
-	GObjectClass * parent_class;
-	ValaDelegate * self;
-	klass = VALA_DELEGATE_CLASS (g_type_class_peek (VALA_TYPE_DELEGATE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_DELEGATE (obj);
-	{
-		vala_delegate_set_cinstance_parameter_position (self, ((double) (-1)));
-		vala_delegate_set_carray_length_parameter_position (self, ((double) (-3)));
-		vala_delegate_set_cdelegate_target_parameter_position (self, ((double) (-3)));
-	}
-	return obj;
-}
-
-
-static void vala_delegate_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDelegate * self;
-	self = VALA_DELEGATE (object);
-	switch (property_id) {
-		case VALA_DELEGATE_RETURN_TYPE:
-		g_value_set_object (value, vala_delegate_get_return_type (self));
-		break;
-		case VALA_DELEGATE_HAS_TARGET:
-		g_value_set_boolean (value, vala_delegate_get_has_target (self));
-		break;
-		case VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION:
-		g_value_set_double (value, vala_delegate_get_cinstance_parameter_position (self));
-		break;
-		case VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION:
-		g_value_set_double (value, vala_delegate_get_carray_length_parameter_position (self));
-		break;
-		case VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION:
-		g_value_set_double (value, vala_delegate_get_cdelegate_target_parameter_position (self));
-		break;
-		case VALA_DELEGATE_NO_ARRAY_LENGTH:
-		g_value_set_boolean (value, vala_delegate_get_no_array_length (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_delegate_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDelegate * self;
-	self = VALA_DELEGATE (object);
-	switch (property_id) {
-		case VALA_DELEGATE_RETURN_TYPE:
-		vala_delegate_set_return_type (self, g_value_get_object (value));
-		break;
-		case VALA_DELEGATE_HAS_TARGET:
-		vala_delegate_set_has_target (self, g_value_get_boolean (value));
-		break;
-		case VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION:
-		vala_delegate_set_cinstance_parameter_position (self, g_value_get_double (value));
-		break;
-		case VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION:
-		vala_delegate_set_carray_length_parameter_position (self, g_value_get_double (value));
-		break;
-		case VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION:
-		vala_delegate_set_cdelegate_target_parameter_position (self, g_value_get_double (value));
-		break;
-		case VALA_DELEGATE_NO_ARRAY_LENGTH:
-		vala_delegate_set_no_array_length (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_delegate_class_init (ValaDelegateClass * klass) {
 	vala_delegate_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_delegate_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDelegatePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_delegate_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_delegate_set_property;
-	G_OBJECT_CLASS (klass)->constructor = vala_delegate_constructor;
-	G_OBJECT_CLASS (klass)->finalize = vala_delegate_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_delegate_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_delegate_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_delegate_real_get_cname;
@@ -686,37 +601,31 @@ static void vala_delegate_class_init (ValaDelegateClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_get_value_function = vala_delegate_real_get_get_value_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_set_value_function = vala_delegate_real_get_set_value_function;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_delegate_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_HAS_TARGET, g_param_spec_boolean ("has-target", "has-target", "has-target", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION, g_param_spec_double ("cinstance-parameter-position", "cinstance-parameter-position", "cinstance-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_delegate_instance_init (ValaDelegate * self) {
 	self->priv = VALA_DELEGATE_GET_PRIVATE (self);
-	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->type_parameters = ((GeeList*) (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)));
+	self->priv->parameters = ((GeeList*) (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)));
 }
 
 
-static void vala_delegate_finalize (GObject * obj) {
+static void vala_delegate_finalize (ValaCodeNode* obj) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (obj);
-	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
+	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (gee_collection_object_unref (self->priv->type_parameters), NULL)));
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (gee_collection_object_unref (self->priv->parameters), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
-	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
-	G_OBJECT_CLASS (vala_delegate_parent_class)->finalize (obj);
+	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_delegate_parent_class)->finalize (obj);
 }
 
 
 GType vala_delegate_get_type (void) {
 	static GType vala_delegate_type_id = 0;
 	if (vala_delegate_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegate), 0, (GInstanceInitFunc) vala_delegate_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegate), 0, (GInstanceInitFunc) vala_delegate_instance_init, NULL };
 		vala_delegate_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaDelegate", &g_define_type_info, 0);
 	}
 	return vala_delegate_type_id;
