@@ -24,6 +24,7 @@
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valaerrorcode.h>
 #include <vala/valamethod.h>
 #include <vala/valasourcereference.h>
@@ -35,7 +36,6 @@
 #include <vala/valaformalparameter.h>
 #include <vala/valavaluetype.h>
 #include <vala/valadatatype.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 
@@ -69,7 +69,7 @@ static char* vala_error_domain_real_get_marshaller_type_name (ValaTypeSymbol* ba
 static char* vala_error_domain_real_get_get_value_function (ValaTypeSymbol* base);
 static char* vala_error_domain_real_get_set_value_function (ValaTypeSymbol* base);
 static gpointer vala_error_domain_parent_class = NULL;
-static void vala_error_domain_dispose (GObject * obj);
+static void vala_error_domain_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -82,27 +82,30 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source_reference reference to source code
  * @return                 newly created error domain
  */
-ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference) {
-	ValaErrorDomain * self;
+ValaErrorDomain* vala_error_domain_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+	ValaErrorDomain* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ERROR_DOMAIN, 0, NULL);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	self = ((ValaErrorDomain*) (g_type_create_instance (object_type)));
+	self = ((ValaErrorDomain*) (vala_typesymbol_construct (object_type, name, source_reference)));
 	return self;
 }
 
 
+ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference) {
+	return vala_error_domain_construct (VALA_TYPE_ERROR_DOMAIN, name, source_reference);
+}
+
+
 /**
  * Appends the specified code to the list of error codes.
  *
  * @param ecode an error code
  */
 void vala_error_domain_add_code (ValaErrorDomain* self, ValaErrorCode* ecode) {
-	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
-	g_return_if_fail (VALA_IS_ERROR_CODE (ecode));
-	gee_collection_add (GEE_COLLECTION (self->priv->codes), ecode);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ecode)), VALA_SYMBOL (ecode));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (ecode != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->codes)), ecode);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) (self))), vala_symbol_get_name (((ValaSymbol*) (ecode))), ((ValaSymbol*) (ecode)));
 }
 
 
@@ -112,11 +115,11 @@ void vala_error_domain_add_code (ValaErrorDomain* self, ValaErrorCode* ecode) {
  * @param m a method
  */
 void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
-	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
-	g_return_if_fail (VALA_IS_METHOD (m));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (m != NULL);
 	if (VALA_IS_CREATION_METHOD (m)) {
-		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "construction methods may only be declared within classes and structs");
-		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
+		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) (m))), "construction methods may only be declared within classes and structs");
+		vala_code_node_set_error (((ValaCodeNode*) (m)), TRUE);
 		return;
 	}
 	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
@@ -124,13 +127,13 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 		ValaValueType* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_value_type_new (VALA_TYPESYMBOL (self)))), NULL)));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
+		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", ((ValaDataType*) ((_tmp0 = vala_value_type_new (((ValaTypeSymbol*) (self)))))), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) (m))), vala_symbol_get_name (((ValaSymbol*) (vala_method_get_this_parameter (m)))), ((ValaSymbol*) (vala_method_get_this_parameter (m))));
 	}
-	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (m)), VALA_SYMBOL (m));
+	gee_collection_add (((GeeCollection*) (self->priv->methods)), m);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) (self))), vala_symbol_get_name (((ValaSymbol*) (m))), ((ValaSymbol*) (m)));
 }
 
 
@@ -140,8 +143,8 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
  * @return list of error codes
  */
 GeeList* vala_error_domain_get_codes (ValaErrorDomain* self) {
-	g_return_val_if_fail (VALA_IS_ERROR_DOMAIN (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->codes));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->codes)));
 }
 
 
@@ -151,23 +154,23 @@ GeeList* vala_error_domain_get_codes (ValaErrorDomain* self) {
  * @return list of methods
  */
 GeeList* vala_error_domain_get_methods (ValaErrorDomain* self) {
-	g_return_val_if_fail (VALA_IS_ERROR_DOMAIN (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->methods));
+	g_return_val_if_fail (self != NULL, NULL);
+	return ((GeeList*) (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->methods)));
 }
 
 
 static void vala_error_domain_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaErrorDomain*) (base));
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_error_domain (visitor, self);
 }
 
 
 static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaErrorDomain*) (base));
+	g_return_if_fail (visitor != NULL);
 	{
 		GeeList* ecode_collection;
 		int ecode_it;
@@ -176,8 +179,8 @@ static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCode
 			ValaErrorCode* ecode;
 			ecode = ((ValaErrorCode*) (gee_list_get (GEE_LIST (ecode_collection), ecode_it)));
 			{
-				vala_code_node_accept (VALA_CODE_NODE (ecode), visitor);
-				(ecode == NULL ? NULL : (ecode = (g_object_unref (ecode), NULL)));
+				vala_code_node_accept (((ValaCodeNode*) (ecode)), visitor);
+				(ecode == NULL ? NULL : (ecode = (vala_code_node_unref (ecode), NULL)));
 			}
 		}
 	}
@@ -189,8 +192,8 @@ static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCode
 			ValaMethod* m;
 			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
-				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
-				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				vala_code_node_accept (((ValaCodeNode*) (m)), visitor);
+				(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 			}
 		}
 	}
@@ -200,13 +203,13 @@ static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCode
 static char* vala_error_domain_real_get_cname (ValaTypeSymbol* base, gboolean const_type) {
 	ValaErrorDomain * self;
 	const char* _tmp2;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	if (self->priv->cname == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) (self))))), vala_symbol_get_name (((ValaSymbol*) (self)))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
@@ -217,13 +220,13 @@ static char* vala_error_domain_real_get_cname (ValaTypeSymbol* base, gboolean co
 static char* vala_error_domain_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaErrorDomain * self;
 	const char* _tmp2;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	if (self->priv->lower_case_cprefix == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->lower_case_cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp1);
+		self->priv->lower_case_cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_symbol_get_lower_case_cname (((ValaSymbol*) (self)), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp1);
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
@@ -233,11 +236,11 @@ static char* vala_error_domain_real_get_lower_case_cprefix (ValaSymbol* base) {
 
 static char* vala_error_domain_get_lower_case_csuffix (ValaErrorDomain* self) {
 	const char* _tmp1;
-	g_return_val_if_fail (VALA_IS_ERROR_DOMAIN (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
+		self->priv->lower_case_csuffix = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) (self)))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp0);
 	}
 	_tmp1 = NULL;
 	return (_tmp1 = self->priv->lower_case_csuffix, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
@@ -249,14 +252,14 @@ static char* vala_error_domain_real_get_lower_case_cname (ValaSymbol* base, cons
 	char* _tmp1;
 	char* _tmp0;
 	char* _tmp2;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	if (infix == NULL) {
 		infix = "";
 	}
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	_tmp2 = NULL;
-	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), infix, (_tmp1 = vala_error_domain_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+	return (_tmp2 = g_strdup_printf ("%s%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) (self))))), infix, (_tmp1 = vala_error_domain_get_lower_case_csuffix (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 }
 
 
@@ -264,16 +267,16 @@ static char* vala_error_domain_real_get_upper_case_cname (ValaTypeSymbol* base,
 	ValaErrorDomain * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_utf8_strup ((_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL)), -1), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_utf8_strup ((_tmp0 = vala_symbol_get_lower_case_cname (((ValaSymbol*) (self)), infix)), -1), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 static gboolean vala_error_domain_real_is_reference_type (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	return FALSE;
 }
 
@@ -281,7 +284,7 @@ static gboolean vala_error_domain_real_is_reference_type (ValaTypeSymbol* base)
 static void vala_error_domain_set_cname (ValaErrorDomain* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
-	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
@@ -297,13 +300,13 @@ static void vala_error_domain_set_cname (ValaErrorDomain* self, const char* cnam
  */
 char* vala_error_domain_get_cprefix (ValaErrorDomain* self) {
 	const char* _tmp2;
-	g_return_val_if_fail (VALA_IS_ERROR_DOMAIN (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cprefix == NULL) {
 		char* _tmp1;
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self), NULL))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
+		self->priv->cprefix = (_tmp1 = g_strdup_printf ("%s_", (_tmp0 = vala_typesymbol_get_upper_case_cname (((ValaTypeSymbol*) (self)), NULL))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
@@ -320,7 +323,7 @@ char* vala_error_domain_get_cprefix (ValaErrorDomain* self) {
 void vala_error_domain_set_cprefix (ValaErrorDomain* self, const char* cprefix) {
 	char* _tmp1;
 	const char* _tmp0;
-	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (cprefix != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
@@ -329,8 +332,8 @@ void vala_error_domain_set_cprefix (ValaErrorDomain* self, const char* cprefix)
 
 
 static void vala_error_domain_process_ccode_attribute (ValaErrorDomain* self, ValaAttribute* a) {
-	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
-	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -363,7 +366,7 @@ static void vala_error_domain_process_ccode_attribute (ValaErrorDomain* self, Va
 				_tmp3 = NULL;
 				filename = (_tmp3 = *filename_it, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 				{
-					vala_typesymbol_add_cheader_filename (VALA_TYPESYMBOL (self), filename);
+					vala_typesymbol_add_cheader_filename (((ValaTypeSymbol*) (self)), filename);
 					filename = (g_free (filename), NULL);
 				}
 			}
@@ -378,21 +381,21 @@ static void vala_error_domain_process_ccode_attribute (ValaErrorDomain* self, Va
  * Process all associated attributes.
  */
 void vala_error_domain_process_attributes (ValaErrorDomain* self) {
-	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
+	g_return_if_fail (self != NULL);
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = VALA_CODE_NODE (self)->attributes;
+		a_collection = ((ValaCodeNode*) (self))->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_error_domain_process_ccode_attribute (self, a);
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -401,36 +404,36 @@ void vala_error_domain_process_attributes (ValaErrorDomain* self) {
 
 static char* vala_error_domain_real_get_type_id (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	return g_strdup ("G_TYPE_POINTER");
 }
 
 
 static char* vala_error_domain_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	return g_strdup ("POINTER");
 }
 
 
 static char* vala_error_domain_real_get_get_value_function (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	return g_strdup ("g_value_get_pointer");
 }
 
 
 static char* vala_error_domain_real_get_set_value_function (ValaTypeSymbol* base) {
 	ValaErrorDomain * self;
-	self = VALA_ERROR_DOMAIN (base);
+	self = ((ValaErrorDomain*) (base));
 	return g_strdup ("g_value_set_pointer");
 }
 
 
 static void vala_error_domain_class_init (ValaErrorDomainClass * klass) {
 	vala_error_domain_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_error_domain_finalize;
 	g_type_class_add_private (klass, sizeof (ValaErrorDomainPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_error_domain_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_error_domain_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_error_domain_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_error_domain_real_get_cname;
@@ -447,28 +450,28 @@ static void vala_error_domain_class_init (ValaErrorDomainClass * klass) {
 
 static void vala_error_domain_instance_init (ValaErrorDomain * self) {
 	self->priv = VALA_ERROR_DOMAIN_GET_PRIVATE (self);
-	self->priv->codes = GEE_LIST (gee_array_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->codes = ((GeeList*) (gee_array_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)));
+	self->priv->methods = ((GeeList*) (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)));
 }
 
 
-static void vala_error_domain_dispose (GObject * obj) {
+static void vala_error_domain_finalize (ValaCodeNode* obj) {
 	ValaErrorDomain * self;
 	self = VALA_ERROR_DOMAIN (obj);
-	(self->priv->codes == NULL ? NULL : (self->priv->codes = (g_object_unref (self->priv->codes), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
+	(self->priv->codes == NULL ? NULL : (self->priv->codes = (gee_collection_object_unref (self->priv->codes), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->cprefix = (g_free (self->priv->cprefix), NULL);
 	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
-	G_OBJECT_CLASS (vala_error_domain_parent_class)->dispose (obj);
+	VALA_CODE_NODE_CLASS (vala_error_domain_parent_class)->finalize (obj);
 }
 
 
 GType vala_error_domain_get_type (void) {
 	static GType vala_error_domain_type_id = 0;
-	if (G_UNLIKELY (vala_error_domain_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorDomainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_domain_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorDomain), 0, (GInstanceInitFunc) vala_error_domain_instance_init };
+	if (vala_error_domain_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorDomainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_domain_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorDomain), 0, (GInstanceInitFunc) vala_error_domain_instance_init, NULL };
 		vala_error_domain_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaErrorDomain", &g_define_type_info, 0);
 	}
 	return vala_error_domain_type_id;
