@@ -53,17 +53,17 @@ ValaInstanceCast* vala_instance_cast_construct (GType object_type, ValaCCodeExpr
 	ValaInstanceCast* self;
 	ValaCCodeIdentifier* _tmp1;
 	char* _tmp0;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type), NULL);
+	g_return_val_if_fail (expr != NULL, NULL);
+	g_return_val_if_fail (type != NULL, NULL);
 	self = ((ValaInstanceCast*) (g_type_create_instance (object_type)));
 	vala_instance_cast_set_inner (self, expr);
 	vala_instance_cast_set_type_reference (self, type);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	vala_ccode_function_call_set_call (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ((_tmp0 = vala_typesymbol_get_upper_case_cname (self->priv->_type_reference, NULL))))));
+	vala_ccode_function_call_set_call (((ValaCCodeFunctionCall*) (self)), ((ValaCCodeExpression*) ((_tmp1 = vala_ccode_identifier_new ((_tmp0 = vala_typesymbol_get_upper_case_cname (self->priv->_type_reference, NULL)))))));
 	(_tmp1 == NULL ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL)));
 	_tmp0 = (g_free (_tmp0), NULL);
-	vala_ccode_function_call_add_argument (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION (self->priv->_inner));
+	vala_ccode_function_call_add_argument (((ValaCCodeFunctionCall*) (self)), VALA_CCODE_EXPRESSION (self->priv->_inner));
 	return self;
 }
 
@@ -74,19 +74,19 @@ ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaTypeSym
 
 
 ValaTypeSymbol* vala_instance_cast_get_type_reference (ValaInstanceCast* self) {
-	g_return_val_if_fail (VALA_IS_INSTANCE_CAST (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_type_reference;
 }
 
 
 void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaTypeSymbol* value) {
-	g_return_if_fail (VALA_IS_INSTANCE_CAST (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_type_reference = value;
 }
 
 
 ValaCCodeExpression* vala_instance_cast_get_inner (ValaInstanceCast* self) {
-	g_return_val_if_fail (VALA_IS_INSTANCE_CAST (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_inner;
 }
 
@@ -94,7 +94,7 @@ ValaCCodeExpression* vala_instance_cast_get_inner (ValaInstanceCast* self) {
 void vala_instance_cast_set_inner (ValaInstanceCast* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
-	g_return_if_fail (VALA_IS_INSTANCE_CAST (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL))), _tmp2);
