@@ -32,53 +32,57 @@ struct _ValaInterfaceTypePrivate {
 
 #define VALA_INTERFACE_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_TYPE, ValaInterfaceTypePrivate))
 enum  {
-	VALA_INTERFACE_TYPE_DUMMY_PROPERTY,
-	VALA_INTERFACE_TYPE_INTERFACE_SYMBOL
+	VALA_INTERFACE_TYPE_DUMMY_PROPERTY
 };
 static ValaDataType* vala_interface_type_real_copy (ValaDataType* base);
 static char* vala_interface_type_real_get_cname (ValaDataType* base);
 static gpointer vala_interface_type_parent_class = NULL;
-static void vala_interface_type_dispose (GObject * obj);
+static void vala_interface_type_finalize (ValaCodeNode* obj);
 
 
 
+ValaInterfaceType* vala_interface_type_construct (GType object_type, ValaInterface* interface_symbol) {
+	ValaInterfaceType* self;
+	g_return_val_if_fail (interface_symbol != NULL, NULL);
+	self = ((ValaInterfaceType*) (g_type_create_instance (object_type)));
+	vala_interface_type_set_interface_symbol (self, interface_symbol);
+	return self;
+}
+
+
 ValaInterfaceType* vala_interface_type_new (ValaInterface* interface_symbol) {
-	ValaInterfaceType * self;
-	g_return_val_if_fail (VALA_IS_INTERFACE (interface_symbol), NULL);
-	self = g_object_newv (VALA_TYPE_INTERFACE_TYPE, 0, NULL);
-	vala_interface_type_set_interface_symbol (self, interface_symbol);
-	return self;
+	return vala_interface_type_construct (VALA_TYPE_INTERFACE_TYPE, interface_symbol);
 }
 
 
 static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 	ValaInterfaceType * self;
 	ValaInterfaceType* result;
-	self = VALA_INTERFACE_TYPE (base);
+	self = ((ValaInterfaceType*) (base));
 	result = vala_interface_type_new (self->priv->_interface_symbol);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-	vala_data_type_set_value_owned (VALA_DATA_TYPE (result), vala_data_type_get_value_owned (VALA_DATA_TYPE (self)));
-	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_dynamic (VALA_DATA_TYPE (result), vala_data_type_get_is_dynamic (VALA_DATA_TYPE (self)));
-	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
+	vala_code_node_set_source_reference (((ValaCodeNode*) (result)), vala_code_node_get_source_reference (((ValaCodeNode*) (self))));
+	vala_data_type_set_value_owned (((ValaDataType*) (result)), vala_data_type_get_value_owned (((ValaDataType*) (self))));
+	vala_data_type_set_nullable (((ValaDataType*) (result)), vala_data_type_get_nullable (((ValaDataType*) (self))));
+	vala_data_type_set_is_dynamic (((ValaDataType*) (result)), vala_data_type_get_is_dynamic (((ValaDataType*) (self))));
+	vala_data_type_set_floating_reference (((ValaDataType*) (result)), vala_data_type_get_floating_reference (((ValaDataType*) (self))));
 	{
 		GeeList* arg_collection;
 		int arg_it;
-		arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (self));
+		arg_collection = vala_data_type_get_type_arguments (((ValaDataType*) (self)));
 		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaDataType* arg;
 			arg = ((ValaDataType*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
 				ValaDataType* _tmp0;
 				_tmp0 = NULL;
-				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp0 = vala_data_type_copy (arg)));
-				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
+				vala_data_type_add_type_argument (((ValaDataType*) (result)), (_tmp0 = vala_data_type_copy (arg)));
+				(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+				(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
 			}
 		}
-		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
+		(arg_collection == NULL ? NULL : (arg_collection = (gee_collection_object_unref (arg_collection), NULL)));
 	}
-	return VALA_DATA_TYPE (result);
+	return ((ValaDataType*) (result));
 }
 
 
@@ -86,62 +90,31 @@ static char* vala_interface_type_real_get_cname (ValaDataType* base) {
 	ValaInterfaceType * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = VALA_INTERFACE_TYPE (base);
+	self = ((ValaInterfaceType*) (base));
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%sIface*", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_interface_symbol), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%sIface*", (_tmp0 = vala_typesymbol_get_cname (((ValaTypeSymbol*) (self->priv->_interface_symbol)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 ValaInterface* vala_interface_type_get_interface_symbol (ValaInterfaceType* self) {
-	g_return_val_if_fail (VALA_IS_INTERFACE_TYPE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_interface_symbol;
 }
 
 
 void vala_interface_type_set_interface_symbol (ValaInterfaceType* self, ValaInterface* value) {
-	g_return_if_fail (VALA_IS_INTERFACE_TYPE (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_interface_symbol = value;
 }
 
 
-static void vala_interface_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaInterfaceType * self;
-	self = VALA_INTERFACE_TYPE (object);
-	switch (property_id) {
-		case VALA_INTERFACE_TYPE_INTERFACE_SYMBOL:
-		g_value_set_object (value, vala_interface_type_get_interface_symbol (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_interface_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaInterfaceType * self;
-	self = VALA_INTERFACE_TYPE (object);
-	switch (property_id) {
-		case VALA_INTERFACE_TYPE_INTERFACE_SYMBOL:
-		vala_interface_type_set_interface_symbol (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_interface_type_class_init (ValaInterfaceTypeClass * klass) {
 	vala_interface_type_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_interface_type_finalize;
 	g_type_class_add_private (klass, sizeof (ValaInterfaceTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_interface_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_interface_type_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_interface_type_dispose;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_interface_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_interface_type_real_get_cname;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_TYPE_INTERFACE_SYMBOL, g_param_spec_object ("interface-symbol", "interface-symbol", "interface-symbol", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -150,17 +123,17 @@ static void vala_interface_type_instance_init (ValaInterfaceType * self) {
 }
 
 
-static void vala_interface_type_dispose (GObject * obj) {
+static void vala_interface_type_finalize (ValaCodeNode* obj) {
 	ValaInterfaceType * self;
 	self = VALA_INTERFACE_TYPE (obj);
-	G_OBJECT_CLASS (vala_interface_type_parent_class)->dispose (obj);
+	VALA_CODE_NODE_CLASS (vala_interface_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_interface_type_get_type (void) {
 	static GType vala_interface_type_type_id = 0;
-	if (G_UNLIKELY (vala_interface_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceType), 0, (GInstanceInitFunc) vala_interface_type_instance_init };
+	if (vala_interface_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceType), 0, (GInstanceInitFunc) vala_interface_type_instance_init, NULL };
 		vala_interface_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaInterfaceType", &g_define_type_info, 0);
 	}
 	return vala_interface_type_type_id;
