@@ -21,13 +21,13 @@
  */
 
 #include <vala/valapropertyaccessor.h>
-#include <vala/valaproperty.h>
 #include <vala/valablock.h>
 #include <vala/valabasicblock.h>
+#include <vala/valacodevisitor.h>
+#include <vala/valaproperty.h>
+#include <vala/valasourcereference.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valatypesymbol.h>
-#include <vala/valasourcereference.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 
@@ -66,14 +66,14 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
 	ValaTypeSymbol* _tmp2;
 	ValaTypeSymbol* t;
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_cname != NULL) {
 		const char* _tmp0;
 		_tmp0 = NULL;
 		return (_tmp0 = self->priv->_cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	}
 	_tmp2 = NULL;
-	t = (_tmp2 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (self->priv->_prop))), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
+	t = (_tmp2 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (((ValaSymbol*) (self->priv->_prop)))), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
 	if (self->priv->_readable) {
 		char* _tmp3;
 		char* _tmp4;
@@ -81,7 +81,7 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
 		_tmp3 = NULL;
 		_tmp4 = NULL;
 		_tmp5 = NULL;
-		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s_get_%s", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp5);
+		return (_tmp5 = (_tmp4 = g_strdup_printf ("%s_get_%s", (_tmp3 = vala_symbol_get_lower_case_cname (((ValaSymbol*) (t)), NULL)), vala_symbol_get_name (((ValaSymbol*) (self->priv->_prop)))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp5);
 	} else {
 		char* _tmp6;
 		char* _tmp7;
@@ -89,7 +89,7 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
 		_tmp6 = NULL;
 		_tmp7 = NULL;
 		_tmp8 = NULL;
-		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s_set_%s", (_tmp6 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (t), NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_prop))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp8);
+		return (_tmp8 = (_tmp7 = g_strdup_printf ("%s_set_%s", (_tmp6 = vala_symbol_get_lower_case_cname (((ValaSymbol*) (t)), NULL)), vala_symbol_get_name (((ValaSymbol*) (self->priv->_prop)))), (_tmp6 = (g_free (_tmp6), NULL)), _tmp7), (t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL))), _tmp8);
 	}
 	(t == NULL ? NULL : (t = (vala_code_node_unref (t), NULL)));
 }
@@ -107,14 +107,12 @@ char* vala_property_accessor_get_cname (ValaPropertyAccessor* self) {
  */
 ValaPropertyAccessor* vala_property_accessor_construct (GType object_type, gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaPropertyAccessor* self;
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = ((ValaPropertyAccessor*) (g_type_create_instance (object_type)));
 	vala_property_accessor_set_readable (self, readable);
 	vala_property_accessor_set_writable (self, writable);
 	vala_property_accessor_set_construction (self, construction);
 	vala_property_accessor_set_body (self, body);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
 	return self;
 }
 
@@ -126,18 +124,18 @@ ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean wr
 
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPropertyAccessor * self;
-	self = VALA_PROPERTY_ACCESSOR (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaPropertyAccessor*) (base));
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_property_accessor (visitor, self);
 }
 
 
 static void vala_property_accessor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPropertyAccessor * self;
-	self = VALA_PROPERTY_ACCESSOR (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaPropertyAccessor*) (base));
+	g_return_if_fail (visitor != NULL);
 	if (self->priv->_body != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
+		vala_code_node_accept (((ValaCodeNode*) (self->priv->_body)), visitor);
 	}
 }
 
@@ -146,11 +144,11 @@ static void vala_property_accessor_real_accept_children (ValaCodeNode* base, Val
  * Process all associated attributes.
  */
 void vala_property_accessor_process_attributes (ValaPropertyAccessor* self) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = VALA_CODE_NODE (self)->attributes;
+		a_collection = ((ValaCodeNode*) (self))->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp1;
 			ValaAttribute* a;
@@ -172,67 +170,67 @@ void vala_property_accessor_process_attributes (ValaPropertyAccessor* self) {
 
 
 ValaProperty* vala_property_accessor_get_prop (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_prop;
 }
 
 
 void vala_property_accessor_set_prop (ValaPropertyAccessor* self, ValaProperty* value) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_prop = value;
 }
 
 
 gboolean vala_property_accessor_get_readable (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_readable;
 }
 
 
 void vala_property_accessor_set_readable (ValaPropertyAccessor* self, gboolean value) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_readable = value;
 }
 
 
 gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_writable;
 }
 
 
 void vala_property_accessor_set_writable (ValaPropertyAccessor* self, gboolean value) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_writable = value;
 }
 
 
 gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_construction;
 }
 
 
 void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboolean value) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_construction = value;
 }
 
 
 ValaSymbolAccessibility vala_property_accessor_get_access (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	return self->priv->_access;
 }
 
 
 void vala_property_accessor_set_access (ValaPropertyAccessor* self, ValaSymbolAccessibility value) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_access = value;
 }
 
 
 ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_body;
 }
 
@@ -240,7 +238,7 @@ ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self) {
 void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* value) {
 	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
@@ -248,7 +246,7 @@ void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* val
 
 
 ValaBasicBlock* vala_property_accessor_get_entry_block (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_entry_block;
 }
 
@@ -256,7 +254,7 @@ ValaBasicBlock* vala_property_accessor_get_entry_block (ValaPropertyAccessor* se
 void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBasicBlock* value) {
 	ValaBasicBlock* _tmp2;
 	ValaBasicBlock* _tmp1;
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_basic_block_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (vala_basic_block_unref (self->priv->_entry_block), NULL))), _tmp2);
@@ -264,7 +262,7 @@ void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBas
 
 
 ValaBasicBlock* vala_property_accessor_get_exit_block (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_exit_block;
 }
 
@@ -272,7 +270,7 @@ ValaBasicBlock* vala_property_accessor_get_exit_block (ValaPropertyAccessor* sel
 void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasicBlock* value) {
 	ValaBasicBlock* _tmp2;
 	ValaBasicBlock* _tmp1;
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_basic_block_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (vala_basic_block_unref (self->priv->_exit_block), NULL))), _tmp2);
@@ -280,19 +278,19 @@ void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasi
 
 
 gboolean vala_property_accessor_get_automatic_body (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	return self->priv->_automatic_body;
 }
 
 
 void vala_property_accessor_set_automatic_body (ValaPropertyAccessor* self, gboolean value) {
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_automatic_body = value;
 }
 
 
 ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_value_parameter;
 }
 
@@ -300,7 +298,7 @@ ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAcc
 void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value) {
 	ValaFormalParameter* _tmp2;
 	ValaFormalParameter* _tmp1;
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (vala_code_node_unref (self->priv->_value_parameter), NULL))), _tmp2);
