@@ -34,15 +34,14 @@ struct _ValaReturnStatementPrivate {
 
 #define VALA_RETURN_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_RETURN_STATEMENT, ValaReturnStatementPrivate))
 enum  {
-	VALA_RETURN_STATEMENT_DUMMY_PROPERTY,
-	VALA_RETURN_STATEMENT_RETURN_EXPRESSION
+	VALA_RETURN_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_return_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_return_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_return_statement_parent_class = NULL;
 static ValaStatementIface* vala_return_statement_vala_statement_parent_iface = NULL;
-static void vala_return_statement_finalize (GObject * obj);
+static void vala_return_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -53,31 +52,34 @@ static void vala_return_statement_finalize (GObject * obj);
  * @param source_reference  reference to source code
  * @return                  newly created return statement
  */
-ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expression, ValaSourceReference* source_reference) {
-	ValaReturnStatement * self;
-	g_return_val_if_fail (return_expression == NULL || VALA_IS_EXPRESSION (return_expression), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_RETURN_STATEMENT, 0, NULL);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+ValaReturnStatement* vala_return_statement_construct (GType object_type, ValaExpression* return_expression, ValaSourceReference* source_reference) {
+	ValaReturnStatement* self;
+	self = ((ValaReturnStatement*) (g_type_create_instance (object_type)));
+	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source_reference);
 	vala_return_statement_set_return_expression (self, return_expression);
 	return self;
 }
 
 
+ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expression, ValaSourceReference* source_reference) {
+	return vala_return_statement_construct (VALA_TYPE_RETURN_STATEMENT, return_expression, source_reference);
+}
+
+
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaReturnStatement*) (base));
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_return_statement (visitor, self);
 }
 
 
 static void vala_return_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = ((ValaReturnStatement*) (base));
+	g_return_if_fail (visitor != NULL);
 	if (vala_return_statement_get_return_expression (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_return_statement_get_return_expression (self)), visitor);
+		vala_code_node_accept (((ValaCodeNode*) (vala_return_statement_get_return_expression (self))), visitor);
 		vala_code_visitor_visit_end_full_expression (visitor, vala_return_statement_get_return_expression (self));
 	}
 }
@@ -85,9 +87,9 @@ static void vala_return_statement_real_accept_children (ValaCodeNode* base, Vala
 
 static void vala_return_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
+	self = ((ValaReturnStatement*) (base));
+	g_return_if_fail (old_node != NULL);
+	g_return_if_fail (new_node != NULL);
 	if (vala_return_statement_get_return_expression (self) == old_node) {
 		vala_return_statement_set_return_expression (self, new_node);
 	}
@@ -95,7 +97,7 @@ static void vala_return_statement_real_replace_expression (ValaCodeNode* base, V
 
 
 ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement* self) {
-	g_return_val_if_fail (VALA_IS_RETURN_STATEMENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_return_expression;
 }
 
@@ -103,55 +105,23 @@ ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value) {
 	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
-	g_return_if_fail (VALA_IS_RETURN_STATEMENT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_return_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL))), _tmp2);
+	self->priv->_return_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (vala_code_node_unref (self->priv->_return_expression), NULL))), _tmp2);
 	if (self->priv->_return_expression != NULL) {
-		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_expression), VALA_CODE_NODE (self));
-	}
-	g_object_notify (((GObject *) (self)), "return-expression");
-}
-
-
-static void vala_return_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (object);
-	switch (property_id) {
-		case VALA_RETURN_STATEMENT_RETURN_EXPRESSION:
-		g_value_set_object (value, vala_return_statement_get_return_expression (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_return_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (object);
-	switch (property_id) {
-		case VALA_RETURN_STATEMENT_RETURN_EXPRESSION:
-		vala_return_statement_set_return_expression (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+		vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_return_expression)), ((ValaCodeNode*) (self)));
 	}
 }
 
 
 static void vala_return_statement_class_init (ValaReturnStatementClass * klass) {
 	vala_return_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_return_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaReturnStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_return_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_return_statement_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_return_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_return_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_return_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_return_statement_real_replace_expression;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_RETURN_STATEMENT_RETURN_EXPRESSION, g_param_spec_object ("return-expression", "return-expression", "return-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -165,18 +135,18 @@ static void vala_return_statement_instance_init (ValaReturnStatement * self) {
 }
 
 
-static void vala_return_statement_finalize (GObject * obj) {
+static void vala_return_statement_finalize (ValaCodeNode* obj) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (obj);
-	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL)));
-	G_OBJECT_CLASS (vala_return_statement_parent_class)->finalize (obj);
+	(self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (vala_code_node_unref (self->priv->_return_expression), NULL)));
+	VALA_CODE_NODE_CLASS (vala_return_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_return_statement_get_type (void) {
 	static GType vala_return_statement_type_id = 0;
 	if (vala_return_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReturnStatement), 0, (GInstanceInitFunc) vala_return_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReturnStatement), 0, (GInstanceInitFunc) vala_return_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_return_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_return_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaReturnStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_return_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
