@@ -55,13 +55,13 @@ static void vala_typecheck_finalize (ValaCodeNode* obj);
  */
 ValaTypeCheck* vala_typecheck_construct (GType object_type, ValaExpression* expr, ValaDataType* type, ValaSourceReference* source) {
 	ValaTypeCheck* self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (expr != NULL, NULL);
+	g_return_val_if_fail (type != NULL, NULL);
+	g_return_val_if_fail (source != NULL, NULL);
 	self = ((ValaTypeCheck*) (g_type_create_instance (object_type)));
 	vala_typecheck_set_expression (self, expr);
 	vala_typecheck_set_type_reference (self, type);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_code_node_set_source_reference (((ValaCodeNode*) (self)), source);
 	return self;
 }
 
@@ -73,27 +73,27 @@ ValaTypeCheck* vala_typecheck_new (ValaExpression* expr, ValaDataType* type, Val
 
 static void vala_typecheck_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTypeCheck * self;
-	self = VALA_TYPECHECK (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (self->priv->_expression), visitor);
-	vala_code_node_accept (VALA_CODE_NODE (vala_typecheck_get_type_reference (self)), visitor);
+	self = ((ValaTypeCheck*) (base));
+	g_return_if_fail (visitor != NULL);
+	vala_code_node_accept (((ValaCodeNode*) (self->priv->_expression)), visitor);
+	vala_code_node_accept (((ValaCodeNode*) (vala_typecheck_get_type_reference (self))), visitor);
 	vala_code_visitor_visit_type_check (visitor, self);
-	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
+	vala_code_visitor_visit_expression (visitor, ((ValaExpression*) (self)));
 }
 
 
 static gboolean vala_typecheck_real_is_pure (ValaExpression* base) {
 	ValaTypeCheck * self;
-	self = VALA_TYPECHECK (base);
+	self = ((ValaTypeCheck*) (base));
 	return vala_expression_is_pure (self->priv->_expression);
 }
 
 
 static void vala_typecheck_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaTypeCheck * self;
-	self = VALA_TYPECHECK (base);
-	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	self = ((ValaTypeCheck*) (base));
+	g_return_if_fail (old_type != NULL);
+	g_return_if_fail (new_type != NULL);
 	if (vala_typecheck_get_type_reference (self) == old_type) {
 		vala_typecheck_set_type_reference (self, new_type);
 	}
@@ -101,7 +101,7 @@ static void vala_typecheck_real_replace_type (ValaCodeNode* base, ValaDataType*
 
 
 ValaExpression* vala_typecheck_get_expression (ValaTypeCheck* self) {
-	g_return_val_if_fail (VALA_IS_TYPECHECK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_expression;
 }
 
@@ -109,7 +109,7 @@ ValaExpression* vala_typecheck_get_expression (ValaTypeCheck* self) {
 void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value) {
 	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
-	g_return_if_fail (VALA_IS_TYPECHECK (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL))), _tmp2);
@@ -117,7 +117,7 @@ void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value)
 
 
 ValaDataType* vala_typecheck_get_type_reference (ValaTypeCheck* self) {
-	g_return_val_if_fail (VALA_IS_TYPECHECK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_data_type;
 }
 
@@ -125,11 +125,11 @@ ValaDataType* vala_typecheck_get_type_reference (ValaTypeCheck* self) {
 void vala_typecheck_set_type_reference (ValaTypeCheck* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
-	g_return_if_fail (VALA_IS_TYPECHECK (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	vala_code_node_set_parent_node (((ValaCodeNode*) (self->priv->_data_type)), ((ValaCodeNode*) (self)));
 }
 
 
